#
# spec file for package gh
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2024 Andreas Stieger <Andreas.Stieger@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define goflags "-buildmode=pie -trimpath -mod=vendor -modcacherw"
%define sname cli
Name:           gh
Version:        2.72.0
Release:        1.1
Summary:        The official CLI for GitHub
License:        MIT
URL:            https://cli.github.com/
Source0:        %{sname}-%{version}.tar.zst
Source1:        vendor.tar.gz
BuildRequires:  fish
BuildRequires:  git-core
BuildRequires:  zstd
BuildRequires:  golang(API) >= 1.23
# This is needed for some tests
BuildRequires:  openssh-clients
BuildRequires:  openssh-common
BuildRequires:  zsh
Requires:       git-core

%description
Official CLI client for GitHub written in Go

%package bash-completion
Summary:        Bash Completion for %{name}
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (gh and bash-completion)
BuildArch:      noarch

%description bash-completion
Bash command line completion support for %{name}.

%package zsh-completion
Summary:        ZSH Completion for %{name}
Requires:       %{name} = %{version}
Supplements:    (gh and zsh)
BuildArch:      noarch

%description zsh-completion
ZSH command line completion support for %{name}.

%package fish-completion
Summary:        Fish completion for %{name}
Requires:       %{name} = %{version}
Supplements:    (gh and fish)
BuildArch:      noarch

%description fish-completion
Fish command line completion support for %{name}.

%prep
%autosetup -n %{sname}-%{version} -a 1
# Upstream decided to tweak Makefile for easier cross-compiling. But the tweak
# overrides variables so we need to remove them to pass GOFLAGS.
sed -i 's/GOOS= GOARCH= GOARM= GOFLAGS= CGO_ENABLED=//g' Makefile

%build
export GOFLAGS="-buildmode=pie -trimpath -mod=vendor -modcacherw -ldflags=-linkmode=external"
%make_build GH_VERSION="v%{version}" bin/gh manpages

%install
bin/gh completion -s bash | install -Dm644 /dev/stdin \
       %{buildroot}%{_datadir}/bash-completion/completions/gh
bin/gh completion -s zsh  | install -Dm644 /dev/stdin \
       %{buildroot}%{_datadir}/zsh/site-functions/_gh
bin/gh completion -s fish | install -Dm644 /dev/stdin \
       %{buildroot}%{_datadir}/fish/vendor_completions.d/gh.fish

install -Dm755 bin/gh %{buildroot}%{_bindir}/gh
install -d %{buildroot}%{_mandir}/man1/
cp share/man/man1/* %{buildroot}%{_mandir}/man1

%check
GOFLAGS=%{goflags} go test ./... -skip "TestNewInspectCmd|TestAccessiblePrompter"

%files
%doc README.md
%license LICENSE
%{_bindir}/gh
%{_mandir}/man1/*

%files bash-completion
%{_datadir}/bash-completion/completions/gh

%files zsh-completion
%{_datadir}/zsh/site-functions/_gh

%files fish-completion
%{_datadir}/fish/vendor_completions.d/gh.fish

%changelog
* Mon May  5 2025 Pavel Dostál <pdostal@suse.com>
- Fix the package tests:
  * Ignore TestNewInspectCmd
  https://github.com/cli/cli/issues/10926
  * Ignore TestAccessiblePrompter
  https://github.com/cli/cli/issues/10916
* Sat May  3 2025 Andrea Manzini <andrea.manzini@suse.com>
- Update to version 2.72.0:
  * Introduce gh accessibility help topic highlighting GitHub CLI accessibility
    experiences
  * [gh pr view] Support closingIssuesReferences JSON field
  * Fix expected error output of TestRepo/repo-set-default
  * Ensure accessible password and auth token prompters disable echo mode
  * Fix: Accessible multiselect prompt respects default selections
- Update to version 2.71.2:
  * Fix pr create when push.default tracking and no merge ref
- Update to version 2.71.1:
  * Fix pr create when branch name contains slashes
- Update to version 2.71.0:
  * gh pr create: Support Git's @{push} revision syntax for determining
    head ref
  * Introduce option to opt-out of spinners
  * Update configuration support for accessible colors
  * gh config: add config settings for accessible prompter and disabling spinner
  * Fix multi pages search for gh search
  * Fix: project commands use shared progress indicator
  * Issue commands should parse args early
  * Feature detect v1 projects on issue view and edit
  * Feature detect v1 projects on web and non web-mode issue create
  * Refactor Sigstore verifier logic
  * bump deps
* Tue Apr 15 2025 pdostal@suse.com
- Update to version 2.70.0:
  * Explain job log resolution reason
  * Document UNKNOWN STEP in run view
  * Add `$` anchor to log file regexps
  * Test normal job run log is preferred over legacy one
  * Prefer normal job run log file over legacy one
  * Explain when a negative number prefix appears
  * Improve explanation for missing step logs
  * Explain the `UNKNWON STEP` placeholder
  * Replace `UNKNOWN` with `UNKNOWN STEP` in job run log
  * Explain why step logs are preferred
  * test(prompter): fix invalid comment
  * test(prompter):  fix race condition
  * Ensure markdown confirm prompt shows editor name
  * fix(prompter): remove needless default value assignment
  * test(prompter): doc how accessible prompter tests work
  * test(prompter): describe why echo is editorcmd
  * test(prompter): use *testing.T instead
  * Add missing `gc.AssertExpectations` calls
  * Add tests for `IsPinned` method
  * Simplify cosign verification example by not using a regex.
  * chore: go mod tidy
  * fix(prompter): pass io to `huh` and refactor tests
  * fix(prompter): update `huh` and fix tests
  * refactor(prompter): rename speechSynthesizerFriendlyPrompter to accessiblePrompter
  * doc(prompter env): accessible prompter includes braille reader
  * chore: go mod tidy
  * Merge pull request #10749 from malancas/update-to-sigstore-go-v0.7.1
  * Update pkg/cmd/run/shared/presentation.go
  * Apply suggestions from code review
  * Test for explicit config disable of label colors
  * Use truthy value for `GH_COLOR_LABELS`
  * test(prompter):  re-add skipped test for accessible confirm default
  * doc(help): label GH_ACCESSIBLE_PROMPTER as preview
  * fix(prompter): rename GH_ACCESSIBLE_PROMPTER
  * refactor(prompter): explicit return values
  * doc(prompter): remove senseless comment
  * refactor(prompter): remove unused variable
  * test(prompter): timeout for tests is 1s
  * fix(prompter): use os.lookupenv for accessible prompter
  * test(prompter): remove needless NO_COLOR set
  * test: use example.com in tests
  * doc: comment typos and formatting
  * test(prompter): add basic survey prompter test
  * test(prompter): fix race conditions
  * doc(envs): speech synthesis prompter
  * Escape dots in regexp pattern in example command
  * Verify fallback to job run logs when step logs are missing
  * Verify job run logs attached in `attachRunLog` test
  * Update `run_log.zip` fixture
  * Fallback to print entire job run log if step logs are missing
  * Add `Log` to `Job` data structure
  * Add `jobLogFilenameRegexp` function
  * Extract job name sanitization as a separate function
  * Deprecate ColorScheme.Gray for ColorScheme.Muted
  * ci: pin third party actions to commit sha
  * doc(prompter): clarify comments
  * refactor(prompter): less magic strings
  * fix(prompter): remove impossible condition
  * fix(prompter): notes about Confirm default
  * fix(prompter): input returns default when blank
  * test(prompter): more tests for bad input
  * Refactor ColorScheme initializer
  * Add label color env var to help topic, unused fix
  * refactor(prompter): rename env var for speech synthesizer friendly prompter
  * docs(prompter): doc prompter interface
  * fix(linter): linter errors
  * test(prompter): move to external package
  * test(prompter): skip vt10x tests on Windows
  * Fix comment language
  * Introduce `color_labels` support, update commands
  * test(prompter): remove needless variable declaration
  * tests(prompter): rename huhprompter
  * test(prompter): replace assert with require
  * fix(prompter): rename huhprompter
  * test(prompter): `go-expect` based prompter tests
  * feat(prompter): include `no` as false-y value
  * test(prompter): remove t.parallel calls
  * fix(md prompter): accessible prompt allows blank
  * feat(md prompter): md prompt respects blankAllowed
  * feat(prompter): add accessible prompter support
  * Remove deprecated note on gray color functions
  * Regenerate mocks
  * Remove configuration setting vestage
  * Remove out of scope configuration setting change
  * Implement tests for muted logic, standardize reset
  * Remove out of scope changes, update list commands
  * Accessible color config boilerplate, colors update
  * Acceptance test issue/pr create/edit with project
  * Update pkg/cmd/attestation/verify/verify.go
  * test(release view): fix indentation
  * doc(formatting): add line breaks for readability
  * Renaming tabl eheader variables for maintainability
  * doc(formatting): update sprig func descriptions
  * test(many): fix whitespace in tests expectations
  * updated test
  * added minor caveat
  * Tweaked language a bit, improved error message.
  * Rewrote the gh at verify --help text to a) clarify and b) document the verificationResult object.
  * doc(run shared): clarify 404 handling
  * Fixes #10590
  * docs: add Sprig library functions to help topics
  * chore: update go-gh to v2.12.0
  * Implement and fix tests for table headers
  * test(run list): update rulesets test name
  * doc(run list): add enterprise ruleset notes
  * refactor(tests): update test name for org workflows
  * docs(run list): doc runs without workflow names
  * fix(run list): do not fail on org workflows
  * Fix typos in CONTRIBUTING.md
  * Underline table headers if colors enabled but no theme
  * Ensure table headers are thematically contrasting
  * [gh ext] Fix `GitKind` extension directory path
  * More cleanup
  * `./script/sign` cleanup
  * Add initial test
  * Show host name in repo creation prompts
* Mon Mar 24 2025 pdostal@suse.com
- Update to version 2.69.0:
  * Curly bracket wrapping acceptance tests
  * Refactor commentable logic
  * Clean up pr/issue comment test names
  * Bring issue/PR comment tests up to par, correct
  * Revert "Merge pull request #10384 from iamazeem/9798-gh-api-encode-package-name"
  * Initial pass fixing gh issue and gh pr comment
  * Bump golang.org/x/net from 0.34.0 to 0.36.0
  * chore: remove redundant word in comment
  * Make missing workflow regexp aware of GitHub App
  * Change issueauto and prauto actions to use the cli-automation env
  * Add environment to prauto and issueauto workflows
  * Add cli-discuss-automation environment to triage.md
  * Separate partitioning from globbing in cmdutil/args package and consumers (#3)
  * Add `exclude` callback function
  * Add tests for - and label args
  * Remove slicing
  * Support globbing for all platforms
  * Add testing to GlobWindowsPaths (#2)
  * Fix `gh gist create` for multiple filenames and glob patterns
  * [gh release create/upload] Expand glob patterns on Windows
* Wed Mar 12 2025 pdostal@suse.com
- Update to version 2.68.1:
  * Fix secret command panic when base repo from cwd
  * Fix(ci): base64 decode GPG passphrase
  * Update pkg/cmd/attestation/verification/attestation.go
  * Update pkg/cmd/attestation/verification/attestation.go
  * Fix acceptance test descriptions
  * Fix gh secret disambiguity test
  * Expand gh secret acceptance tests
  * Expand gh secret base repo tests
  * [gh secret] Check `GH_REPO` too in addition to `--repo` for disambiguation
  * Deep Dive Document Release Process (#10503)
  * Fix unhandled panic in FindWorkflow and add tests
  * Bump actions/attest-build-provenance from 2.2.0 to 2.2.2
  * Fix checkout when URL arg is from fork and cwd is upstream
  * Update `project` help text; fix `unlink` usage
  * Inconsistent format of examples in help text
  * Inconsistent format of description of flags (starting with lowercase letter) (#10507)
  * Update Go version to 1.23 in CONTRIBUTING.md
  * Fix minor auth login help typo
  * Add docs; rename function name
  * Bump github.com/go-jose/go-jose/v4 from 4.0.2 to 4.0.5
  * docs: OAuth doc link moves to newline
  * fix expected test output
  * undo regex changes
  * remove signer-ref option
  * chore: update go version in devcontainer
  * docs: warn about process revoking all tokens
  * docs: document how to revoke `gh` OAuth tokens
  * refactor: use a more straightforward return value
  * Test pr checkout force on different branch
  * [gh pr checkout] Add --no-tags option to git fetch commands in checkout logic
  * Allow injection of TUFMetadataDir in tests
  * Refactor remote resolver caching tests
  * Fix `remoteResolver` caching issue
  * Address pr comments
  * Add test for item-edit --number 0
  * Support setting project item number to 0
  * Wrap error
  * Rename flag to `--fail-on-no-commits`
  * Update tests
  * Fix non-TTY case
  * Suggestions to enhance upstream default handling
  * Use API REST Client
  * Use subtests in attestation verification integration tests
  * update default upstream when forking repo
  * Update usage to lower-kebab-case
  * Fix typo in README
  * Add missing <> in gh auth login docs
  * Add mutex to fix race in attestation test client
  * Update tests
  * Remove trailing whitespace
  * Standardize URLs
  * [gh issue/pr comment] Create a comment if no comment already
  * Update tests
  * Address review comments
  * Align no default repo message with other uses
  * [gh release create] Fail when there are no new commits since the most recent release
  * Use API without shorthand flag
  * Update tests
  * [gh api] Escape package name (URL encoding) for packages endpoint
  * remove custom transport
  * var naming
  * dedup local bundle err handling
  * Update tests
  * Add test cases for succeed on no cache and api errors for --all (#1)
  * Remove short (abbreviated) flag support
  * Address PR review comments
  * add checks to cert extensions func
  * fix option ordering
  * fix issues causing tests to fail
  * add signer and source ref, commit options
  * Bump github.com/spf13/pflag from 1.0.5 to 1.0.6
  * [gh repo view] Improve error message for forked repo
  * [gh cache delete --all] Add `--succeed-on-no-caches` flag to return exit code 0
  * set new options in enforcement criteria
  * reorder fields
  * add new signing options
* Wed Feb 12 2025 pdostal@suse.com
- Update to version 2.67.0:
  * Exit with error if no matching predicate type exists
  * Fix logic error in contributing docs
  * Improve http error test cases
  * Handle non-TTY behavior
  * Do not try to parse bodies for HEAD requests
  * Update pkg/cmd/pr/status/status.go
  * Collapse related instructions
  * Remove redundant instructions
  * Update language
  * [gh pr status] Mention `gh pr checks` in the `Long` section
  * Update release doc content
  * Doc: Clarify guidelines for `help wanted` issues and prs
  * Bump google.golang.org/protobuf from 1.36.4 to 1.36.5
  * Update tests
  * [gh project item-edit] Fix number type
  * Address review comments
  * Address review comments
  * Revert breaking change
  * Revert "[gh repo edit] Allow setting commit message defaults"
  * Use HTML numeric code instead of escaping with slash
  * [gh config] Escape pipe symbol in Long desc for website manual
  * Ensure item iteration field is populated in tests
  * Drop accidental help text change
  * Error when `gh repo rename` is used with a new repo name that contains an owner
  * [gh repo edit] Allow setting commit title defaults
  * Rename staggler
  * Formatting
  * AuoLink -> Autolink
  * Use http constants
  * refac and some spacing in output
  * More consistency
  * whitespace
  * clean up
  * Autolink delete http tests
  * Revert change to deps
  * Autolink delete tests
  * Initial working implementation
  * remove duplicated Prompter type
  * revert isEqualSet to private
  * Revert color changes
  * [docs/releasing.md] Add basic info for homebrew update flow
  * consolidate tests around getBundle func when possible
  * change permanent backoff error condition
  * Remove unused env var, PRID
  * dont retry when parsing fails
  * Update test
  * [gh issue/pr list] Improve help text
  * [gh extensions install] Improve help text and error message
  * [gh api] Fix mutual exclusion messages of `--slurp` flag
  * Remove v1 project 'add to board' automation from prauto workflow
  * [gh project item-list] Add `iterationId` field in ProjectV2ItemFieldIterationValue
  * [gh workflow run] Improve error handling for `--ref` flag
  * update tests
  * add missing return statement
  * method update
  * update no attestations found err
  * remove old tests
  * drop unneeded methods
  * deduplicate get attestation code
  * fix tests
  * update testing
  * chore: remove unused file
  * feat: integrate new PRLister into pr list command
  * issue #2329: create shared PRLister
  * fix: tab format may break checkout prompts
  * issue #2329: handle empty list of PR
  * issue #2329: include PR status in the prompt's options
  * issue #2329: fix prompt header getting duplicated
  * issue #2329: simplify the UI of the prompt
  * issue #2329: update the prompt's format
  * issue #2329: fix unit tests
  * issue cli#2329: Fix linter
  * issue cli#2329: fix unsufficent properties required for PR checkout
  * issue #2329: move Interactive check to RunE
  * fix: update the copy
  * issue #2329: return error when not running interactively
  * issue #2329: fix missing stub
  * issue #2329: improve UI/UX
  * issue #2329: add happy path unit test
  * issue #2329: fix the linting issue
  * issue #2329: fix the unit tests issue - ensure its backward compatible
  * feat: let user select pr to checkout
* Tue Feb 11 2025 pdostal@suse.com
- Update to version 2.66.1:
  * Address PR comments
  * Remove unused ErrNoGitRepository error
  * Handle error from ParsePRRefs when the selector is provided
  * Add comment to status recognizing when we require a repo
  * Refactor finder to work with URL selectors
  * Add tests for using the pr Finder outside of repo
  * Update deployment.yml
  * update tests to account for logic flip
  * flip bundle fetching logic
  * Update formatting for autolink output
  * Rename PRRefs to PullRequestRefs and PR comment cleanup
  * Remove redundant error check
  * Keeping autolink IDs the same in all test cases
  * Expand test case
  * Remove unused test field
  * Remove unused test field
  * Use `defer` instead
  * Error case test for viewRun
  * Autolink view HTTP tests
  * Shorten description
  * Updates following renaming domain to shared
  * Partial testing for view
  * Initial, working implementation
  * Stop progress indicator on failure (`gh run list --workflow`)
  * Cleaned up some naming and comments
  * Minor refactoring autolink create help and logic
  * Bump github.com/in-toto/attestation from 1.1.0 to 1.1.1
  * Cleanup comment
  * Fix pr create tests
  * Fix breaking changes from sigstore-go v0.7.0 upgrade
  * go mod tidy
  * Upgrade sigstore-go to v0.7.0: fixes #10114 formatting issue
  * Refactor pr status to use the ParsePRRefs helper on the Finder
  * Moved remote.pushDefault out of ReadBranchConfig and into finder
  * Remove @{push} from branch config
  * Add PushDefault method to git client
  * WIP: push default defaults to simple
  * Error if push revision doesn't match a remote
  * Bump google.golang.org/protobuf from 1.36.3 to 1.36.4
  * Refactor finder.Find and replace parseCurrentBranch with parsePRRefs
  * Bump actions/attest-build-provenance from 2.1.0 to 2.2.0
  * remove bolding from bullet point output
  * Update test to be compatible with latest Glamour v0.8.0
  * reorder policy enforcement criteria print out
  * bold bullet point list header text
  * Enable MSI building for Windows arm64
  * chore: fix some comments
  * Bump go module version to 1.23
  * Bump github.com/google/go-containerregistry from 0.20.2 to 0.20.3
  * Remove unncessary printf usage
  * Bump golang ci lint to work with go 1.24
  * Fix: Ensure constant format strings in fmt and printf calls
  * Change back to exponential backoff
  * Linter
  * Better handling for codespace state polling
  * Add affected version to bug report form
  * fix: tiny typo fix
  * Fix: accidental whitespace in gist edit
  * Fix: gist edit test name
  * Fix: gist edit/view tests var name consistency
  * Fix: Gist edit tests for interactivity
  * Add small wait to extension update tests
  * Refactor test based on PR feedback
  * fixup! Add comments and a bit of code cleanup
  * Use PushRemoteURL instead of RemoteURL in prSelectorForCurrentBranch
  * Add comments and a bit of code cleanup
  * skip check
  * add tty check
  * formatting
  * delete unused function
  * drop unused handler method
  * print attestation output info as bullet points instead of table
  * Bump google.golang.org/protobuf from 1.36.2 to 1.36.3
  * Fix typo in secret base repo selection comment
  * Change wording on secret repo prompt
  * Print informative message before prompting for secret repo
  * Secret base repo prompting should not use resolved remote
  * Move secret base repo prompting earlier
  * Add acceptance test for secrets remote disambiguation
  * Remove validated TODO and add review warning
  * Rename secret BaseRepo func
  * Use smarter base repo funcs for secret commands
  * Move secret repo validation into secrets subpackage
  * Always prompt on secret set when multiple remotes
  * Update setdefault test
  * Update docs for set-default
  * Prompt for secret commands
  * Add tests for secret commands
  * Add remote check to secret commands
  * Add missing git stubs to tests
  * Add tests for deleteGist
  * Make extension update check non-blocking
  * Update pkg/cmd/attestation/verify/verify.go
  * add install instructions for Manjaro Linux
  * Bump github.com/gabriel-vasile/mimetype from 1.4.7 to 1.4.8
  * #10042: Attempt to add a new test scenario for handling error messages when TTY is unavailable
  * Rename domain pkg to shared
  * #10042: Applied code review suggestions to view_test.go
  * show error message for rerun workflow older than a month ago
  * Enhance help docs on ext upgrade notices
  * fix tests
  * fix tests
  * gist delete - check no gists
  * removed unnecessary space
  * Update pkg/cmd/gist/edit/edit.go
  * chore: fix some function names in comment
  * drop description from prompts, fix tests
  * Expand docs on cleaning extension update dir
  * Simplifying cleanExtensionUpdateDir logic
  * Separate logic for checking updates
  * Capture greater detail on updaterEnabled
  * Restore old error functionality of prSelectorForCurrentBranch
  * Change error handling on ReadBranchConfig to respect git Exit Codes
  * fix: add back colon that I removed
  * fix: actually read how MaxFunc work and simplify the code
  * fix: padded display
  * Collapse dryrun checks in ext bin upgrade
  * Bump github.com/mattn/go-colorable from 0.1.13 to 0.1.14
  * Bump github.com/sigstore/protobuf-specs from 0.3.2 to 0.3.3
  * gist delete - use  in confirmation and success info
  * Rename test user in tests
  * Change pr number in test
  * Surface and handle error from ReadBranchConfig in parseCurrentBranch
  * Directly stub headBranchConfig in Test_tryDetermineTrackingRef
  * Refactor error handling in ReadBranchConfig to avoid panic
  * Refine error handling of ReadBranchConfig
  * Add test for empty BranchConfig in prSelectorForCurrentBranch
  * #10042 removed unnecessary field
  * Correct help documentation around template use in `gh issue create`
  * #10042: Add error messages for 'gh gist view/edit' prompts when no TTY is detected
  * Comment exported functions
  * fix gist description in tests
  * gist delete prompt with gist description
  * Remove shadowed errors from prSelectorForCurrentBranch and cover with tests
  * Added tests to cover prSelectorForCurrentBranch for confidence in refactor
  * Refactor prSelectorForCurrentBranch and tests
  * Add missing test for RemoteURL in parseBranchConfig
  * update table column headers
  * Change ReadBranchConfig error message in gh pr create
  * Remove private readBranchConfig method and remove parseBranchConfig from Client
  * update test fixtures to include buildConfigURI
  * add check for invalid attestation
  * tentative updates for acceptance criteria - pending confirmation re description in prompt
  * PR review edits
  * Refactor Test_readGitBranchConfig for easier parsing
  * update tests to use new function name
  * Update pkg/cmd/attestation/api/client.go
  * Update pkg/cmd/attestation/api/client.go
  * Remove named return values from prSelectorForCurrentBranch
  * Refactor ReadBranchConfig for test coverage of newly returned erros
  * Remove named returns from ReadBranchConfig and surface errors
  * remove old comment
  * remove commented out code
  * comment
  * undo more name chanages
  * undo other name change
  * remove spaces
  * undo name change for now
  * more mock http client cleanup
  * Update triage.md to reflect FR experiment outcome
  * simplify mock http client
  * use mock to assert number of http calls
  * add http client test constructors
  * setup testing struct for test cases
  * feat: make the extension upgrade fancier
  * Fix up intra-org fork test setup
  * Add renamed acceptance tests
  * Reflect coverage for view and status subcommands
  * Expand with gh pr status
  * Add base gh pr view acceptance tests for changes
  * Find push remote using branch.<name>.pushRemote and remote.pushDefault
  * Only find PRs w/ branch.<name>.merge if push.default = upstream/tracking
  * Find PRs using @{push}
  * add mutex for test field
  * add test case for bundle url fetch failure
  * add tests for bundle url fetch and fallback
  * fetch bundles in parallel
  * return fetch attestations err directly
  * provide additional logging and fallback
  * Update pkg/cmd/auth/login/login.go
  * Clear up --with-token fine grained PAT usage
  * Fix typos
  * feat: Add support for creating autolink references
  * cleanup
  * gist delete prompt for confirmation
  * undo extra move
  * rearrange struct vals for consistency
  * add gist delete tests for blank gist id
  * gh gist delete: prompt for gist id
  * Escape '.' in version validation regex in deployment workflow
  * Add job to deployment workflow to validate the tag name for a given release
  * update verify output table
  * simplify func params
  * add more verification integration tests
  * fix failing tests
  * add mock http client
  * update error messages
  * var naming
  * go mod tidy
  * add httpClient field to LiveClient struct
  * remove unused method
  * fetch bundles with sas url
  * Fix failig local extension tests
  * Implement remaining PR feedback
  * Implement partial feedback before trunk update
  * Add build constraint for non-Windows systems
  * Add build constraint for non-Windows systems
  * Refactor local installation manager test by OS
  * #10042 fixed test
  * fixing gh gist view prompts with no TTY
  * Remove unnecessary Extension.FullName()
  * Expand update tests for local extensions
  * Test whether extension update should be checked
  * Remove Extension.FullName() from interface
  * Enhance extension manager and tests
  * Initial extension update check testing
  * Refactor extension command testing
  * Bring extension update check in line with gh check
  * initial pass at fetching bundles with sas urls
* Wed Jan 15 2025 pdostal@suse.com
- Update to version 2.65.0:
  * Bump cli/go-gh for indirect security vulnerability
  * Panic mustParseTrackingRef if format is incorrect
  * Move trackingRef into pr create package
  * Make tryDetermineTrackingRef tests more respective of reality
  * Rework tryDetermineTrackingRef tests
  * Avoid pointer return from determineTrackingBranch
  * Doc determineTrackingBranch
  * Don't use pointer for determineTrackingBranch branchConfig
  * Panic if tracking ref can't be reconstructed
  * Document and rework pr create tracking branch lookup
  * Upgrade generated workflows
  * Fixed test for stdout in non-tty use case of repo fork
  * Fix test
  * Alternative: remove LocalBranch from BranchConfig
  * Set LocalBranch even if the git config fails
  * Add test for permissions check for security and analysis edits (#1)
  * print repo url to stdout
  * Update pkg/cmd/auth/login/login.go
  * Move mention of classic token to correct line
  * Separate type decrarations
  * Add mention of classic token in gh auth login docs
  * Update pkg/cmd/repo/create/create.go
  * docs(repo): make explicit which branch is used when creating a repo
  * fix(repo fork): add non-TTY output when fork is newly created
  * Move api call to editRun
  * Complete get -> list renaming
  * Better error testing for autolink TestListRun
  * Decode instead of unmarshal
  * Use 'list' instead of 'get' for autolink list type and method
  * Remove NewAutolinkClient
  * Break out autolink list json fields test
  * PR nits
  * Refactor autolink subcommands into their own packages
  * Whitespace
  * Refactor out early return in test code
  * Add testing for AutoLinkGetter
  * Refactor autolink list and test to use http interface for simpler testing
  * Apply PR comment changes
  * Introduce repo autolinks list commands
  * Remove release discussion posts and clean up related block in deployment yml
  * Extract logic into helper function
  * add pending status for workflow runs
  * Feat: Allow setting security_and_analysis settings in gh repo edit
  * Upgrade golang.org/x/net to v0.33.0
  * Document SmartBaseRepoFunc
  * Document BaseRepoFunc
  * Update releasing.md
  * Document how to set gh-merge-base
* Mon Dec 23 2024 pdostal@suse.com
- Update to version 2.64.0:
  * add test for different SAN and SourceRepositoryURI values
  * add test for signerRepo and tenant
  * add some more fields to test that san, sanregex are set properly
  * Bump github.com/cpuguy83/go-md2man/v2 from 2.0.5 to 2.0.6
  * update san and sanregex configuration for readability
  * reduce duplication when creating policy content
  * tweak output of build policy info
  * Name conditionals in PR finder
  * Support pr view for intra-org forks
  * Return err instead of silentError in merge queue check
  * linting pointed out this var is no longer used
  * Removed fun, but inaccessible ASCII header
  * further tweaks to the long description
  * Exit on pr merge with `-d` and merge queue
  * Addressed PR review feedback; expanded Long command help string, used ghrepo, clarified some abbreviations
  * Update pkg/cmd/attestation/inspect/inspect.go
  * Update gh auth commands to point to GitHub Docs
  * Reformat ext install long
  * Mention Windows quirk in ext install help text
  * Fix error mishandling in local ext install
  * Assert on err msg directly in ext install tests
  * Clarify hosts in ext install help text
  * Bump golang.org/x/crypto from 0.29.0 to 0.31.0
  * Removed now redundant file
  * minor tweak to language
  * go mod tidy
  * Deleted no-longer-used code.
  * deleted now-invalid tests, added a tiny patina of new testing.
  * Tightened up docs, deleted dead code, improved printing
  * fix file name creation on windows
  * wording
  * hard code expected digest
  * fix download test
  * use bash shell with integration tests
  * simplify var creation
  * update integration test scripts
  * fix: list branches in square brackets in gh codespace
  * try nesting scripts
  * run all tests in a single script
  * windows for loop syntax
  * use replaceAll
  * update expected file path on windows
  * run integration tests with windows specific syntax
  * run all attestation cmd integration tests automatically
  * Bump actions/attest-build-provenance from 1.4.4 to 2.1.0
  * Improve error handling in apt setup script
  * use different file name for attestation files on windows
  * test(gh run): assert branch names are enclosed in square brackets
  * docs: enhance help text and prompt for rename command
  * Revert "Confirm auto-detected base branch"
  * Confirm auto-detected base branch
  * Merge changes from #10004
  * Set gh-merge-base from `issue develop`
  * Open PR against gh-merge-base
  * Refactor extension executable error handling
  * fix: list branches in square brackets in gh run view (#10038)
  * docs: update description of command
  * style: reformat files
  * docs: update sentence case
  * use github owned oci image
  * docs: add mention of scopes help topic in `auth refresh` command help
  * docs: add mention of scopes help topic in `auth login` command help
  * docs: add help topic for auth scopes
  * docs: improve help for browse command
  * docs: improve docs for browse command as of #5352
  * fix package reference
  * add gh attestation verify integration test for oci bundles
  * add integration test for bundle-from-oci option
  * update tests
  * update tests
  * move content of veriy policy options function into enforcement criteria
  * comment
  * try switch statement
  * remove duplicate err checking
  * get bundle issuer in another func
  * more logic updating to remove nesting
  * inverse logic for less nesting
  * remove unneeded nesting
  * wip, linting, getting tests to pass
  * wording
  * var naming
  * drop table view
  * order policy info so relevant info is printed next to each other
  * Update pkg/cmd/attestation/verification/policy.go
  * Update pkg/cmd/attestation/verification/policy.go
  * Update pkg/cmd/attestation/verification/policy.go
  * wip: added new printSummaryInspection
  * Improve error handling for missing executable
  * experiment with table output
  * Assert stderr is empty in manager_test.go
  * Update error message wording
  * Change: exit zero, still print warning to stderr
  * wording
  * Improve docs on installing extensions
  * Update language for missing extension executable
  * Update test comments about Windows behavior
  * wording
  * wording
  * wording
  * add newlines for additional policy info
  * Document requirements for local extensions
  * Warn when installing local ext with no executable
  * wording
  * formatting
  * print policy information before verifying
  * add initial policy info method
  * more wip poking around, now with table printing
  * wip, gh at inspect will check the signature on the bundle
  * wip: inspect now prints various bundle fields in a nice json
* Fri Dec  6 2024 pdostal@suse.com
- Update to version 2.63.2:
  * include alg with digest when fetching bundles from OCI
  * Error for mutually exclusive json and watch flags
  * Use safepaths for run download
  * Use consistent slice ordering in run download tests
  * Consolidate logic for isolating artifacts
  * Fix PR checkout panic when base repo is not in remotes
  * When renaming an existing remote in `gh repo fork`, log the change
  * Improve DNF version clarity in install steps
  * Fix formatting in client_test.go comments for linter
  * Expand logic and tests to handle edge cases
  * Refactor download testing, simpler file descends
  * Bump github.com/gabriel-vasile/mimetype from 1.4.6 to 1.4.7
  * Improve test names so there is no repetition
  * Second attempt to address exploit
* Mon Dec  2 2024 pdostal@suse.com
- Update to version 2.63.0:
  * Bump cli/go-gh for codespace fix
  * Update git/client_test.go
  * Update git/client_test.go
  * Update git/client_test.go
  * Add checkout test that uses ssh git remote url
  * Rename backwards compatible credentials pattern
  * Fix CredentialPattern doc typos
  * Remove TODOs
  * Fix typos and add tests for CredentialPatternFrom* functions
  * Add SSH remote todo
  * General cleanup and docs
  * Allow repo sync fetch to use insecure credentials pattern
  * Allow client fetch to use insecure credentials pattern
  * Allow client push to use insecure credential pattern
  * Allow client pull to use insecure credential pattern
  * Allow opt-in to insecure pattern
  * Support secure credential pattern
  * Refactor error handling for missing "workflow" scope in createRelease
  * ScopesResponder wraps StatusScopesResponder
  * Refactor `workflow` scope checking
  * pr feedback
  * pr feedback
  * Update pkg/cmd/attestation/verify/attestation_integration_test.go
  * Apply suggestions from code review
  * Refactor command documentation to use heredoc
  * pr feedback
  * remove unused test file
  * undo change
  * add more testing testing fixtures
  * update test with new test bundle
  * naming
  * update test
  * update test
  * Fix README.md code block formatting
  * clean up
  * wrap sigstore and cert ext verification into a single function
  * Adding option to return `baseRefOid` in `pr view`
  * verify cert extensions function should return filtered result list
  * pr feedback
  * Update pkg/cmd/attestation/download/download.go
  * fix function param calls
  * Update pkg/cmd/attestation/verification/extensions.go
  * Formatting fix
  * Updated formatting to be more clear
  * Updated markdown syntax for a `note`.
  * Added a section on manual verification of the relases.
  * Handle missing "workflow" scope in createRelease
  * Modify push prompt on repo create when bare
  * Doc push behaviour for bare repo create
  * Push --mirror on bare repo create
  * Add acceptance test for bare repo create
  * Doc isLocalRepo and git.Client IsLocalRepo differences
  * Use errWithExitCode interface in repo create isLocalRepo
  * Backfill repo creation failure tests
  * Support bare repo creation
  * use logger println method
  * simplify verifyCertExtensions
  * rename type
  * refactor fetch attestations funcs
* Fri Nov 15 2024 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 2.62.0
  * CVE-2024-52308: remote code execution (RCE) when users connect
    to a malicious Codespace SSH server and use the gh codespace
    ssh or gh codespace logs commands
    (boo#1233387, GHSA-p2h2-3vg9-4p87)
  * Check extension for latest version when executed
  * Shorten extension release checking from 3s to 1s
- includes changes from 2.61.0:
  * Enhance gh repo edit command to inform users about
    consequences of changing visibility and ensure users are
    intentional before making irreversible changes
* Sun Oct 27 2024 pdostal@suse.com
- Update to version 2.60.1:
  * Update testscript to use hard fork
  * Note token redaction in Acceptance test README
  * Refactor gpg-key delete to align with ssh-key delete
  * Add acceptance tests for org command
  * Adjust environment help for host and tokens (#9809)
  * Add SSH Key Acceptance test
  * Add Acceptance test for label command
  * Add acceptance test for gpg-key
  * Update go-internal to redact more token types in Acceptance tests
  * Address PR feedback
  * Clarify `gh` is available for GitHub Enterprise Cloud
  * Remove comment from gh auth logout
  * Add acceptance tests for auth-setup-git and formattedStringToEnv helper func
  * Use forked testscript for token redaction
  * Use new GitHub preview terms in working-with-us.md
  * Use new GitHub previews terminology in attestation
  * Test json flags for repo view and list
  * Clean up auth-login-logout acceptance test with native functionality
  * Add --token flag to `gh auth login` to accept a PAT as a flag
  * Setup acceptance testing for auth and tests for auth-token and auth-status
  * Update variable testscripts based on secret
  * Check extOwner for no value instead
  * Fix tests for invalid extension name
  * Refactor to remove code duplication
  * Linting: now that mockDataGenerator has an embedded mock, we ought to have pointer receivers in its funcs.
  * Minor tweaks, added backoff to getTrustDomain
  * added test for verifying we do 3 retries when fetching attestations.
  * Fix single quote not expanding vars
  * Added constant backoff retry to getAttestations.
  * Address @williammartin PR feedback
  * wip: added test that fails in the absence of a backoff.
  * add validation for local ext install
  * feat: add ArchivedAt field to Repository struct
  * Refactor `gh secret` testscript
  * Wrap true in '' in repo-fork-sync
  * Rename acceptance test directory from repos to repo
  * Remove unnecessary flags from repo-delete testscript
  * Replace LICENSE Makefile README.md acceptance api bin build cmd context docs git go.mod go.sum internal pkg script share test utils commands with
  * Wrap boolean strings in '' so it is clear they are strings
  * Remove unnecessary gh auth setup-git steps
  * Cleanup some inconsistencies and improve collapse some functionality
  * Add acceptance tests for repo deploy-key add/list/delete
  * Add acceptance tests for repo-fork and repo-sync
  * Add acceptance test for repo-set-default
  * Add acceptance test for repo-edit
  * Add acceptance tests for repo-list and repo-rename
  * Acceptance testing for repo-archive and repo-unarchive
  * Add acceptance test for repo-clone
  * Added acceptance test for repo-delete
  * Added test function for repos and repo-create test
  * Implement acceptance tests for search commands
  * Remove . from test case for TestTitleSurvey
  * Clean up Title Survey empty title message code
  * Add missing test to trigger acceptance tests
  * Add acceptance tests for `gh variable`
  * Minor polish / consistency
  * Fix typo in custom command doc
  * Refactor env2upper, env2lower; add docs
  * Update secret note about potential failure
  * Add testscripts for `gh secret`, helper cmds
  * Remove stdout assertion from release
  * Rename test files
  * Add acceptance tests for `release` commands
  * Implement basic API acceptance test
  * Remove unnecesary mkdir from download Acceptance test
  * Remove empty stdout checks
  * Adjust sleeps to echos in Acceptance workflows
  * Use regex assert for enable disable workflow Acceptance test
  * Watch for run to end for cancel Acceptance test
  * Include startedAt, completedAt in run steps data
  * Rewrite a sentence in CONTRIBUTING.md
  * Add filtered content output to docs
  * sleep 10s before checking for workflow run
  * Update run-rerun.txtar
  * Create cache-list-delete.txtar
  * Create run-view.txtar
  * Create run-rerun.txtar
  * Create run-download.txtar
  * Create run-delete.txtar
  * Remove IsTenancy and relevant tests from gists as they are unsupported
  * Remove unnecessary code branches
  * Add ghe.com to tests describing ghec data residency
  * Remove comment
  * auth: Removed redundant ghauth.IsTenancy(host) check
  * Use go-gh/auth package for IsEnterprise, IsTenancy, and NormalizeHostname
  * Upgrade go-gh version to 2.11.0
  * Add test coverage to places where IsEnterprise incorrectly covers Tenancy
  * Fix issue creation with metadata regex
  * Create run-cancel.txtar
  * Create workflow-run.txtar
  * Create workflow-view.txtar
  * implement workflow enable/disable acceptance test
  * implement base workflow list acceptance test
  * Add comment to acceptance make target
  * Resolve PR feedback
  * Acceptance test issue command
  * Support GH_ACCEPTANCE_SCRIPT
  * Ensure Acceptance defer failures are debuggable
  * Add acceptance task to makefile
  * build(deps): bump github.com/gabriel-vasile/mimetype from 1.4.5 to 1.4.6
  * Ensure pr create with metadata has assignment
  * Document sharedCmds func in acceptance tests
  * Correct testscript description in Acceptance readme
  * Add link to testscript pkg documentation
  * Add VSCode extension links to Acceptance README
  * Fix GH_HOST / GH_ACCEPTANCE_HOST misuse
  * Acceptance test PR list
  * Support skipping Acceptance test cleanup
  * Acceptance test PR creation with metadata
  * Suggest using legacy PAT for acceptance tests
  * Add host recommendation to Acceptance test docs
  * Don't append remaining text if more matches
  * Highlight matches in table and content
  * Split all newlines, and output no-color to non-TTY
  * Print filtered gists similar to code search
  * Show progress when filtering
  * Simplify description
  * Disallow use of --include-content without --filter
  * Improve help docs
  * Refactor filtering into existing `gist list`
  * Improve performance
  * Add `gist search` command
  * Fix api tests after function signature changes
  * Return nil instead of empty objects when err
  * Fix license list and view tests
  * Validate required env vars not-empty for Acceptance tests
  * Add go to test instructions in Acceptance README
  * Apply suggestions from code review
  * Error if acceptance tests are targeting github or cli orgs
  * Add codecoverage to Acceptance README
  * Isolate acceptance env vars
  * Add Writing Tests section to Acceptance README
  * Add Debug and Authoring sections to Acceptance README
  * Acceptance test PR comment
  * Acceptance test PR merge and rebase
  * Note syntax highlighting support for txtar files
  * Refactor acceptance test environment handling
  * Add initial acceptance test README
  * Use txtar extension for testscripts
  * Support targeting other hosts in acceptance tests
  * Use stdout2env in PR acceptance tests
  * Acceptance test PR checkout
  * Add pr view test script
  * Initial testscript introduction
  * While we're at it, let's ensure VerifyCertExtensions can't be tricked the same way.
  * Add examples for creating `.gitignore` files
  * Update help for license view
  * Refactor http error handling
  * implement `--web` flag for license view
  * Fix license view help doc, add LICENSE.md example
  * Update help and fix heredoc indentation
  * Add SPDX ID to license list output
  * Fix ExactArgs invocation
  * Add `Long` for license list indicating limitations
  * Update function names
  * Reverse repo/shared package name change
  * If provided with zero attestations to verify, the LiveSigstoreVerifier.Verify func should return an error.
  * Bump cli/oauth to 1.1.1
  * Add test coverage for TitleSurvey change
  * Fix failing test for pr and issue create
  * Make the X in the error message red and print with io writer
  * Handle errors from parsing hostname in auth flow
  * Apply suggestions from code review
  * Refactor tests and add new tests
  * Move API calls to queries_repo.go
  * Allow user to override markdown wrap width via $GH_MDWIDTH from environment
  * Add handling of empty titles for Issues and PRs
  * Print the login URL even when opening a browser
  * Apply suggestions from code review
  * Update SECURITY.md
  * Fix typo and wordsmithing
  * fix typo
  * Remove trailing space from heading
  * Revise wording
  * Update docs to allow community submitted designs
  * Implement license view
  * Implement gitignore view
  * implement gitignore list
  * Update license table headings and tests
  * Fix ListLicenseTemplates doc
  * fix output capitalization
  * Cleanup rendering and tests
  * Remove json output option
  * Divide shared repo package and add queries tests
  * First pass at implementing `gh repo license list`
  * Emit a log message when extension installation falls back to a darwin-amd64 binary on an Apple Silicon macOS machine
* Wed Oct  2 2024 pdostal@suse.com
- Update to version 2.58.0:
  * build(deps): bump github.com/theupdateframework/go-tuf/v2
  * Include `dnf5` commands
  * Add GPG key instructions to appropriate sections
  * Update docs language to remove possible confusion around 'where you log in'
  * Change conditional in promptForHostname to better reflect prompter changes
  * Shorten language on Authenticate with a GitHub host.
  * Update language on docstring for `gh auth login`
  * Change prompts for `gh auth login` to reflect change from GHE to Other
  * Sentence case 'Other' option in hostname prompt
  * build(deps): bump github.com/henvic/httpretty from 0.1.3 to 0.1.4
  * Add documentation explaining how to use `hostname` for `gh auth login`
  * Replace "GitHub Enterprise Server" with "other" in `gh auth login` prompt
  * fix tenant-awareness for trusted-root command
  * Fix test
  * Update pkg/cmd/extension/manager.go
  * Update comment formatting
  * Use new HasActiveToken method in trustedroot.go
  * Add HasActiveToken method to AuthConfig interface
  * Add HasActiveToken to AuthConfig.
  * Improve error presentation
  * Improve the suggested command for creating an issue when an extension doesn't have a binary for your platform
  * Update pkg/cmd/attestation/trustedroot/trustedroot_test.go
  * build(deps): bump github.com/cpuguy83/go-md2man/v2 from 2.0.4 to 2.0.5
  * enforce auth for tenancy
  * disable auth check for att trusted-root cmd
  * better error for att verify custom issuer mismatch
  * Enhance gh repo create docs, fix random cmd link
* Wed Sep 18 2024 pdostal@suse.com
- Update to version 2.57.0:
  * Update go-gh to use api subdomains
  * Use api subdomains for commands using ghinstance package
  * Add test for extension install fallback to amd64 on darwin
  * Stub hasRosetta for tests
  * Refactor conditions
  * suppress att verify output when no tty
  * add att verify test for custom OIDC issuer
  * build(deps): bump github.com/sigstore/sigstore-go from 0.6.1 to 0.6.2
  * Suggest installing Rosetta when extension installation fails due to missing `darwin-arm64` binary, but a `darwin-amd64` binary is available
  * This commit introduces tenancy aware attestation policy building.
  * use sigstore-go v0.6.2
  * check specific err
  * check err in GetLocalAttestations
  * go mod tidy
  * check for sigstore-go validation errs
  * get latest sigstore-go commit
  * handle os.PathError in GetLocalAttestations
  * Move non-integration test to different test file
  * print verify err
  * check for os.PathError
  * dont print err content
  * update bundle file parsing err messages
  * Expand active test cases
  * Added `--active` flag to the `gh auth status` command
* Tue Sep 10 2024 pdostal@suse.com
- Update to version 2.56.0:
  * Check for nil values to prevent nil dereference panic
  * build(deps): bump actions/attest-build-provenance from 1.4.2 to 1.4.3
  * Update linux install to point to GPG troubleshoot
  * Revert "Remove note explaining 2 year old GPG ID change"
  * Remove note explaining 2 year old GPG ID change
  * Rename ProtobufBundle to Bundle
  * Upgrade to sigstore-go v0.6.1
  * `gh attestation verify` handles empty JSONL files (#9541)
  * verify 2nd artifact without swapping order (#9532)
  * chore: fix some function names
  * Improve the help message for -F (#9525)
  * build(deps): bump actions/attest-build-provenance from 1.4.1 to 1.4.2 (#9518)
  * "offline" verification using the bundle of attestations without any additional handling of the file (#9523)
  * Drop surplus trailing space char in flag names in web
  * Remove `Internal` from `gh repo create` prompt when owner is not an org (#9465)
  * Fix doc typo for `repo sync`
  * Quote repo names consistently in `gh repo sync` stdout (#9491)
  * fixed the test
  * update error message
  * rename flag to bundle-from-oci
  * fix the trimming of log filenames for `gh run view`
  * Check http scheme as well
  * Fix tests
  * Always print URL scheme to stdout
  * udpate the options
  * addded more test
  * minor fixed
  * minor fixed
  * added test
  * clean naming
  * add contain check
  * refactor the logic and logging
  * tmp
* Wed Aug 21 2024 pdostal@suse.com
- Update to version 2.55.0:
  * Add flox to linux installation instructions
  * Update pkg/cmd/issue/develop/develop.go
  * Update api/queries_branch_issue_reference.go
  * add testing
  * fix behavior for `issue develop -b non-exist-branch`
  * Describe bucket and state JSON fields in pr checks command
  * Fix pr checks exit code (#9452)
  * Add a note about external contributors to `working-with-us.md`
  * Update attestation TUF root
  * include required permissions to generate attestations
  * build(deps): bump github.com/creack/pty from 1.1.21 to 1.1.23 (#9459)
  * Do not generate build attestations for otherBinWorkflow.yml
  * Use latest checkout version, generate attestations, and specify go version file input.
  * Update `gh search issues --project` flag doc to specify `owner/number` syntax
  * Update `gh search prs --project` flag doc to specify `owner/number` syntax
  * build(deps): bump actions/attest-build-provenance from 1.4.0 to 1.4.1
  * Minor grammatical fix
  * Add test cases for PGP, SSH and X.509 signatures
  * Explain why not looking for signature begin marker
  * Wrap flags with backticks, continued
  * Replace `--project.*` flags' `name` with `title` in docs (#9443)
  * Change to requiring bundle v0.2
  * Fix tests
  * Require Sigstore Bundle v0.3 when verifying with `gh attestation`
  * Change `gh repo set-default --view` to print to `stderr` when no default exists (#9431)
  * Document that `gh run download` downloads the latest artifact by default
  * Deduplicate the initialization of editor mode
  * Update docs/triage.md
  * Add Acceptance Criteria requirement to triage.md for accepted issues
  * Add `pr create --editor`
  * build(deps): bump github.com/google/go-containerregistry
  * Fix host handling in variable and secret delete
  * Unify use of tab indent in non-test source files
  * Update `gh variable get` to use repo host
  * build(deps): bump actions/attest-build-provenance from 1.3.3 to 1.4.0
  * Add Flox as an installation option
  * Update tests with changes to `gitTagInfo` function
  * Add example for `--notes-from-tag`
  * Add test for `gitTagInfo`
  * Use signature-stripped tag annotation content
* Sat Aug  3 2024 pdostal@suse.com
- Reenable TestGetTrustedRoot test
- Update to version 2.54.0:
  * update test and remove logic to check SourceRepositoryOwnerURI is empty string
  * update test
  * minor fix
  * update test
  * added
  * handle attest case insensitivity
  * Fix missing variable
  * Use closure-scoped variable to catch `--remove-milestone` option
  * Use closure-scoped variable to catch `--remove-milestone` option
  * build(deps): bump github.com/google/go-containerregistry
  * Verify `--milestone` and `--remove-milestone` are not assignable at the same time
  * Assert correct parsing of `--remove-milestone` option
  * Verify `--body` and `--body-file` are not assignable at the same time
  * Add `--remove-milestone` option
  * Improve `--remove-milestone` option description
  * Point to `Editable.MilestoneId` method
  * build(deps): bump github.com/gabriel-vasile/mimetype from 1.4.4 to 1.4.5
  * Update sigstore-go in gh CLI to v0.5.1 (#9366)
  * Handle `--bare` clone targets (#9271)
  * Slightly clarify when CLI will exit with 4
  * Export databaseId for releases
  * Alphabetise release json fields
  * Add test for release view json export fields
  * Expose fullDatabaseId for PR json export
  * Add examples for template usage in PR and issue creation
  * document exit code behavior
  * Update documentation for gh api PATCH
  * Exit with 1 on authentication failure
  * Verify `--milestone` and `--remove-milestone` are not assignable at the same time
  * Assert correct parsing of `--remove-milestone` option
  * Add `--remove-milestone` option
  * Remove unused expected `output` from test case (with `wantsErr: true`)
  * Verify `--body` and `--body-file` are not assignable at the same time
  * Remove attestation test that requires being online (#9340)
  * Remove redundant whitespace
* Thu Jul 18 2024 pdostal@suse.com
- Update to version 2.53.0:
  * Disable `TestGetTrustedRoot/successfully_verifies_TUF_root` test
    due to https://github.com/cli/cli/issues/8928
  * Fix bsc#1227035 - VUL-0: CVE-2024-6104: gh: hashicorp/go-retryablehttp:
    url might write sensitive information to log file
  * Rename package directory and files
  * Rename package name to `update_branch`
  * Rename `gh pr update` to `gh pr update-branch`
  * Add test case for merge conflict error
  * Handle merge conflict error
  * Return error if PR is not mergeable
  * Replace literals with consts for `Mergeable` field values
  * Add separate type for `PullRequest.Mergeable` field
  * Remove unused flag
  * Print message on stdout instead of stderr
  * Raise error if editor is used in non-tty mode
  * Add tests for JSON field support on issue and pr view commands
  * docs: Update documentation for `gh repo create` to clarify owner
  * Ensure PR does not panic when stateReason is requested
  * build(deps): bump actions/attest-build-provenance from 1.3.2 to 1.3.3
  * Enable to use --web even though editor is enabled by config
  * Add editor hint message
  * Use prefer_editor_prompt config by `issue create`
  * Add prefer_editor_prompt config
  * Add `issue create --editor`
  * Update create.go
  * gh attestation trusted-root subcommand (#9206)
  * Fetch variable selected repo relationship when required
  * Update .github/ISSUE_TEMPLATE/bug_report.md
  * build(deps): bump github.com/hashicorp/go-retryablehttp
  * Update .github/ISSUE_TEMPLATE/bug_report.md
  * Add GH_DEBUG to issue template
  * Add `createdAt` field to tests
  * Add `createdAt` field to `Variable` type
  * Add test for exporting as JSON
  * Add test for JSON output
  * Only populate selected repo information for JSON output
  * Add test to verify JSON exporter gets set
  * Add `--json` option support
  * Use `Variable` type defined in `shared` package
  * Add tests for JSON output
  * Move `Variable` type and `PopulateSelectedRepositoryInformation` func to shared
  * Fix query parameter name
  * Update tests to account for ref comparison step
  * Improve query variable names
  * Check if PR branch is already up-to-date
  * Add `ComparePullRequestBaseBranchWith` function
  * Run `go mod tidy`
  * Add test to verify `--repo` requires non-empty selector
  * Require non-empty selector when `--repo` override is used
  * Run `go mod tidy`
  * Register `update` command
  * Add tests for `pr update` command
  * Add `pr update` command
  * Add `UpdatePullRequestBranch` method
  * Upgrade `shurcooL/githubv4`
* Sat Jul  6 2024 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 2.52.0:
  * Attestation Verification - Buffer Fix
  * Remove beta note from attestation top level command
  * Removed beta note from `gh at download`.
  * Removed beta note from `gh at verify`, clarified reusable workflows use case.
  * add `-a` flag to `gh run list`
* Fri Jun 14 2024 pdostal@suse.com
- Update to version 2.51.0:
  * Gracefully degrade when fetching annotations fails due to 403 (#9113)
  * build(deps): bump google.golang.org/protobuf from 1.34.1 to 1.34.2
  * build(deps): bump github.com/gorilla/websocket from 1.5.1 to 1.5.2
  * Bump go-keyring to fix keepassxc prompt confirmation
  * build(deps): bump goreleaser/goreleaser-action from 5 to 6
  * replaced deprecated --json-result flag with --format=json in the gh at docstring.
  * build(deps): bump actions/attest-build-provenance from 1.1.2 to 1.2.0
  * Specify rpm repository to avoid conflicts with community repositories
  * Add `signer-repo` and `signer-workflow` flags to `gh attestation verify` (#9137)
  * Ensure signed RPMs have attestations
* Thu May 30 2024 pdostal@suse.com
- Update to version 2.50.0:
  * Clarify Mac OS Installer packages are unsigned
  * Build completions during release on macos
  * Add build provenance for gh CLI releases (#9087)
  * Add integration tests for `gh attestation verify` shared workflow use case (#9107)
  * Update readme about MacOS pkg
  * Remove `v` prefix when `pkgmacos` is called
  * Integrate argument array to remove duplicate code
  * build(deps): bump github.com/gabriel-vasile/mimetype from 1.4.3 to 1.4.4
  * Added native min os version blocking
  * Fix distribution.xml + min macos version requirements
  * Added make macospkg target
  * Fix directory already exists
  * Add a `gh variable get FOO` command (#9106)
  * Add comment to pr diff regex
  * Update regex in changedFilesNames to handle quoted paths
  * fix: rename the `Attempts` field to `Attempt`; expose in `gh run view` and `gh run ls` (#8905)
  * Change minimum build script macOS version
  * Cleanup pkgmacos build script
  * Removed redundant specifications
  * Fix indentation
  * Undo goreleaser change
  * feat: add support for stateReason in `gh pr view` (#9080)
  * Fix indentation
  * Fix indentation
  * Indentation fix
  * Update choice title
  * Update pkg title
  * update generated content for man pages and website
  * williammartin simplifications
  * remove no-op if clause that returns 'No Aliases'
  * Conditionalize references, remove redundant alias
  * list the various alias permutations for the command and subcommands
  * Remove TODO and add comment on LoginFlow tests
  * Comment the purpose of the helper config contract
  * Test git credentials are configured in LoginFlow
  * Add HelperConfig contract test and FakeHelperConfig
  * Inject GitCredentialFlow to LoginFlow as test seam
  * Removed unused param flagDryRun from upgradeFunc
  * Added summary TTY message to tests
  * Added TTY message to summarize checking extension upgrades
  * Add Helper test for Windows
  * Add tests for gitcredentials Updater
  * Fix mistaken git installation error check
  * Move gitcredentials HelperConfig and add tests
  * Comment the new gitcredentials package
  * Comment the git credential flow
  * Remove unnecessary credential setup private method
  * Use tighter interface in setup-git
  * Rename gitcredentials Configure to ConfigureOurs
  * Make gitcredential helper smarter
  * Move fetching configured helper into gitcredentials
  * Extract units for configuring and updating git credential helpers
  * removed tty message
  * Implement ExportData to filter json fields
  * fix: rename fields list
  * feat: add json output for PR checks
  * Fix doc bug for gh run watch
  * Fix typo in macOS pkg installer build script
  * Add macOS pkg installer to deployment
* Mon May 13 2024 pdostal@suse.com
- Update to version 2.49.2:
  * build(deps): bump github.com/sigstore/protobuf-specs from 0.3.1 to 0.3.2
  * Add further docs to Option type
  * Comment further on config changes
  * Remove unnecessary config list variable
  * Fix mistaken find and replace for Option type
  * Fix repo fork to use remote protocol if none configured
  * Avoid reconstructing config Options on each use
  * Make config list less fallible
  * Provide more type safety around config values
  * Move config interfaces into gh package (#9060)
  * Fix typos
  * Creating doc to capture Codespace usage guidance
  * Fix test function name
  * Add test to verify JSON fields section is rendered in Markdown
  * Output `JSON Fields` section in Markdown
  * Add test to verify JSON fields section is rendered
  * Add `jsonCmd` test command variable
  * Output `JSON Fields` section
  * Output `JSON FIELDS`
  * Add tests to verify proper `help:json-fields` annotations
  * Add `help:json-fields` annotation
  * Add `FormatSlice` function
  * Add --latest=false example to `release create` command
  * Update create.go
  * Add --latest=false to `gh release create` docs
* Thu May  9 2024 Andreas Stieger <andreas.stieger@gmx.de>
- Reenable all tests
  https://github.com/cli/cli/issues/8928 looks resolved.
- Update to version 2.49.1:
  * Fix `attestation verify` source repository check bug
  * Fix unused params across project
  * Add support for jobs with long filenames
  * Run `attestation` command set integration tests separately
  * build(deps): bump golang.org/x/net from 0.22.0 to 0.23.0
  * Adjust short and long to be the same
  * Do not mutate headers when initialising tableprinter
  * Document relationship between host and active account
* Wed May  1 2024 pdostal@suse.com
- Update to version 2.49.0:
  * Document repo clone protocol behaviour
  * whitespace aligment for inspect/inspect.go
  * whitespace alignment in attestation/attestation.go
  * Added tweaked note to tuf-root-verify
  * Tweaked gh attestation help strings to generate nicer cli manual site.
  * Update attestation's beta designation
  * Update cli/go-gh to v2.9.0
  * Add beta designation on attestation command set
  * Test `gh at verify -b` does not require auth
  * Use ghinstance package for attestation host checks
  * Test cmdutil.IsAuthCheckEnabled cases
  * Fix issue with closing pager stream (#9020)
  * Support long URLs in `gh repo clone` (#9008)
  * check for enterprise host
  * Add missing title field for projectv2
  * Match query fields with `ProjectV2` type
  * Include `URL` in `ProjectV2` type
  * Include `projectsV2` in GraphQL query
  * Remove unnecessary defensive check
  * Test verification failures when attestations are bad
  * Rework sigstore tests for easier maintenance
  * Make error more obvious when bundle has wrong extension
  * Add colon at the end of secret prompts (#9004)
  * Use cmdutil.ExactArgs instead of MinimumArgs; also add tests
  * proof of concept for flag-level disable auth check
  * remove hidden flag from attestation command (#8998)
  * Update `gh attestation verify` output (#8991)
  * Just base verification policy on trusted root, not bundle
  * Support offline mode for `gh attestation verify`
  * build(deps): bump google.golang.org/grpc from 1.62.1 to 1.62.2
  * `gh attestation tuf-root-verify` offline test fix (#8975)
  * Update `sigstore-go` dependency to v0.3.0 (#8977)
  * build(deps): bump golang.org/x/net from 0.21.0 to 0.23.0
  * Make it clearer that job flag is meant to be an ID
  * Ignore run-id when providing also job for rerun
* Wed Apr 17 2024 pdostal@suse.com
- Update to version 2.48.0:
  * Update install_linux.md (#8950)
  * Remove unnecessary --help comment
  * Fix `go` directive in `go.mod` (#8956)
  * Use `filepath.Join` to support different platforms
  * Run `go mod tidy`
  * Refactor into table tests
  * Explain `--skip-ssh-key` usage in long doc
  * Tidy `go.mod`
  * Fix cache contention in Go CI jobs
  * Fix `attestation` cmd offline unit test failure (#8933)
  * Change subcommands default to be more user friendly
  * Add unit test, update naming, ensure DSSE envelope is in-toto
  * Updates from linter feedback
  * Add support to `attestation` command for more predicate types.
  * Close zip file in run view tests
  * Ensure run log cache creates cache dir if it doesn't exist
  * Test `--skip-ssh-key` is captured correctly
  * Add test to verify skipped SSH key prompts
  * Add `--skip-ssh-key` to options
  * Add `SkipSSHKey` field to `LoginOptions`
  * Add tests for non-happy field paths
  * Fix api cache test
  * Use testify in git url tests
  * Ensure cache dir is always available in RunLogCache
  * Remove RunLogCache interface
  * Use real Run Log Cache in run view tests
  * Capture error on Run Log Cache Exists
  * Rework Run Log Cache so that cache dir is injected
  * Expose CacheDir on Config
  * Minorly refactor scheme normalization in git ParseURL
  * Test for parsing error in git ParseURL
  * Remove naked returns from git ParseURL
  * Fix parsing IPv6 remote URLs (#8893)
  * Add codeowners entry for the GitHub TUF root included in the `attestation` command set (#8919)
  * Add comment to explain `showSelectedReposInfo` assignment
  * Rename const to avoid CodeQL error
  * Add tests to verify `numSelectedRepos` is populated when necessary
  * Populate `numSelectedRepos` only if needed
  * build(deps): bump google.golang.org/grpc from 1.61.1 to 1.61.2
  * Run defers in queue
  * Resolve PR comments
  * Wrap JSON arrays, objects in array with --slurp
  * Resolve PR comments
  * Clarify --merge-pages docs
  * Replace --paginate-all with --merge-pages
  * Resolve test issues
  * Add more JSON merge tests
  * Move jsonmerge package to internal
  * Merge JSON responses from `gh api`
  * Add tests for `FindByRepo`
  * Apply suggestions from code review
  * Improve error message returned by `FindByRepo`
  * Add test cases to verify exported JSON has non-zero `numSelectedRepos`
  * Populate `numSelectedRepos` in non-interactive mode, if explicitly selected
  * Anchor the log filename to the start
  * Add pr url pattern
  * Test pr url lock
  * update example for deeply nested array update
  * allow multiple items in nested array
* Thu Apr  4 2024 pdostal@suse.com
- Update to version 2.47.0:
  * Bump go-gh to v2.8.0 and go mod tidy
  * build(deps): bump github.com/sigstore/protobuf-specs from 0.3.0 to 0.3.1
  * Bump glamour to v0.7.0 and go mod tidy
  * build(deps): bump github.com/google/go-containerregistry
  * build(deps): bump github.com/gorilla/websocket from 1.5.0 to 1.5.1
  * build(deps): bump google.golang.org/grpc from 1.61.0 to 1.61.1
  * Rely on go.mod go version in all workflows (#8911)
  * Upgrade to Go 1.22 (#8836)
  * build(deps): bump github.com/docker/docker
  * build(deps): bump gopkg.in/go-jose/go-jose.v2 from 2.6.1 to 2.6.3
  * gh-attestation cmd integration (#8698)
  * fix segfault in `gh repo rename`
  * Bump go-gh to 2.7.0
  * Fix typo in auth switch help example
* Fri Mar 22 2024 pdostal@suse.com
- Update to version 2.46.0:
  * Include draft ID in project item list JSON (#8754)
  * build(deps): bump github.com/cpuguy83/go-md2man/v2 from 2.0.3 to 2.0.4
  * Document run watch and view not supporting fine grained PATs
  * Document auth switch behaviour for two or more accounts
  * Improve discovery of `gh auth status`
  * grammar: avoid e.g.+etc. together
  * Fix the description of `gh release upload`
  * Bump go-keyring to fix race condition
  * feat: support `dry-run` in gh `pr create` (#8376)
  * build(deps): bump google.golang.org/protobuf from 1.30.0 to 1.33.0
  * fixed doc string
  * remove repetitive word
  * Fix breaking test for PR/issue # change
  * Enhance 2nd round of issue and PR number output
  * Apply first round of owner/repo#number consistency
  * fix: format files
  * feat(merge): add owner/repo in prompt
* Tue Mar  5 2024 pdostal@suse.com
- Update to version 2.45.0:
  * Bump cli/go-gh v2.6.0 for tenant using GH_TOKEN (#8787)
  * Support `project view --web` with TTY (#8773)
  * Handle case: some system set 600 mod for new file.
  * Clarify helptext for `gh search issues` and `gh search repos` regarding archived repos
  * Make minor cache list ref flag adjustments
  * Update incorrect regex comment for client Commits
  * Use regex to split apart the git client Commit logs
  * Use null byte separators when fetching comments from git
  * Add new tests to git client Commits
  * Remove unnecessary split conditional from client Commits
  * Extract new test helper for git client Commits
  * redirect users to the `gh environment` command
  * Revert "make comments in the default config file more informative"
  * make comments in the default config file more informative
  * fixed whitespace
  * Clarify helptext for search prs regarding archived repos
  * bug: fixed the result.Operation variable prior to patchRepoVariable being called in the setVariable function.
  * Remove mainLoop label from garden
  * feat: Add `ref` option to `gh cache list`
  * chore: simplify parameter `owner`
  * Support for `[HOST/]OWNER/REPO` format
  * Replace `assert` with `require` in testing
  * Simplify install command for Debian & Ubuntu
  * Remove `--format` flag and add description for not specifying `--repo` and `--team` flag
  * Fix printed project number
  * Support for directory based repo and `GH_REPO` env variable
  * Change the output of link` and `unlink`
  * Refactor `OrganizationTeam`
  * Replace `httpmock` with `gock` in testing
  * handle flags with `cmdutil.MutuallyExclusive`, and move mutation methods to `queries.go`
  * fix wording, move conditional blocks to functions, and add api to retrieve the ID of a team
  * Fix wording
  * Add testing for link and unlink
  * Support for team
  * Support for unlink
  * Remove support for team
  * Link Project to Repository or Team Command
* Mon Feb 19 2024 pdostal@suse.com
- Update to version 2.44.1:
  * Fix PR create regression around title and body when there is only one commit by @williammartin in #8707
- Update to version 2.44.0:
  * Feature: added Order flag for release list command by @leevic31 in #8632
  * autofill with body by @guerinoni in #8423
  * Add default values to web manual and man pages by @zsloane in #8395
  * build(deps): bump microsoft/setup-msbuild from 1.3.2 to 2.0.0 by @dependabot in #8648
  * Documentation for built-in aliases by @Rebeccasun31 in #8367
  * Add more detail to fork failure message by @chrisroat in #8614
  * feat: Add cache key option to gh cache list by @toshimaru in #8667
* Thu Feb 15 2024 Martin Pluskal <mpluskal@suse.com>
- Update to version 2.43.1:
  * Avoid parsing create or update label http response
  * go mod tidy
  * Upgrade cli/go-gh to v2.5.0 for home-manager fix
  * Fix linting error
  * Parse SSH args before creating the shell
  * Send activity signals during non-interactive codespace SSH command
  * build(deps): bump microsoft/setup-msbuild from 1.3.1 to 1.3.2
  * Specify refspec to push to the correct branch in the event of a conflicting tag
  * Update Arch repo to [extra]
  * added URL for newly created repo (#8574)
  * build(deps): bump actions/cache from 3 to 4 (#8594)
  * Add force flag to setup-git command (#8552)
  * fix: Prevent nil dereference in `pr view`. (#8566)
  * search repos command add usage example for --archived=false (#8391)
  * Add --json export flags to release list command (#8474)
  * Add json export flags to variable list command (#8516)
  * build(deps): bump actions/download-artifact from 3 to 4 (#8466)
  * build(deps): bump actions/upload-artifact from 3 to 4 (#8467)
  * Remove project JSON formatting objects (#8541)
  * Fix some typos raised by codespell
  * Add Webi as an option for installation (#8555)
  * Align devcontainer Go version with go.mod (#8570)
  * Move create codespace permission opt out behind `else` to fix token permissions
  * chore: Unify calling gh in examples (#8560)
  * Mark-up `gh-config` settings with backticks
* Wed Jan 17 2024 pdostal@suse.com
- Update to version 2.42.1:
  * Add Webi as an option for installation (#8555)
  * Align devcontainer Go version with go.mod (#8570)
  * Move create codespace permission opt out behind `else` to fix token permissions
  * chore: Unify calling gh in examples (#8560)
* Mon Jan 15 2024 pdostal@suse.com
- Update to version 2.42.0:
  * Prevent downloading releases with assets that match windows reserved filenames (#8517)
  * Support template, jq flags with standard format flag (#7832)
  * Mark-up `gh-config` settings with backticks
* Wed Jan 10 2024 Martin Pluskal <mpluskal@suse.com>
- Update to version 2.41.0:
  * Update deployment.yml
  * Update pkg/cmd/browse/browse.go
  * build(deps): bump golang.org/x/crypto from 0.14.0 to 0.17.0 (#8473)
  * Ensure Windows sign script fails based on signtool
  * Update deployment workflow for final HSM solution
  * Fix signtool invocation
  * Fix sign script fail conditions
  * Fix HSM goreleaser calling sign script
  * Fix HSM Windows signing
  * Fix issue sourcing signtool for Windows signing
  * build(deps): bump github/codeql-action from 2 to 3
  * Verify the downloaded zip for `gh run view --log`
  * Add missing PowerShell file from previous commit
  * Unify Windows sign process on signtool
  * Add more help message to browse command
* Mon Dec 18 2023 Martin Pluskal <mpluskal@suse.com>
- Restore _service to generate changelog
* Thu Dec 14 2023 Bernhard Wiedemann <bwiedemann@suse.com>
- update to 2.40.1:
  * add Multiple Account Support
  * fix build after 2024-01-06
  * Full changelog https://github.com/cli/cli/compare/v2.38.0...v2.40.1
* Fri Nov 10 2023 Dirk Müller <dmueller@suse.com>
- update to 2.38.0:
  * `extension install` no longer errors unhelpfully if the
    extension is already installed
  * All tables now have headers
  * `project` commands have a clearer error message when no owner
    can be resolved
  * `workflow run` now presents a select for `choice` workflow
    input types
  * `codespace create` no longer polls for additional codespace
    permissions unnecessarily
  * `go install` now works with the removal of our crypto fork
- update to 2.37.0:
  * `project`: Remove `template` field from `--format=json`
    output
  * In v2.34.0 we introduced the `template` field when outputing
    projects to JSON, unfortunately we forgot to take into account
    our GHES users. This field does not exist on GHES 3.8 and older.
    Including this field in our queries and output broke nearly
    all the `project` commands for users targeting these older
    versions of GHES. As we try our hardest to keep `gh` compatible
    with all * non-deprecated GHES versions this was a pretty big
    mistake.  In order to fix it we are reverting the querying and
    exporting of the `template` field for `project` commands. We
    apologize for the inconvenience this may cause, and plan to
    bring back this field once GHES 3.8 gets deprecated.
  * `repo create`: Allow `--disable-issues` and `--template`
    flags to be used together
  * `repo create`: Allow `--homepage` and `--template` flag to be
    used together
  * `repo create`: Allow creating repositories from templates in
    interactive mode
  * `repo fork`: Set default repo when forking repo
  * `codespace`: Migrate all Codespaces operations from Live
    Share to Dev Tunnels
  * `codespace create`: Poll permission acceptance endpoint on
    codespace creation
  * `pr create`: Remove duplicates targets for push survey
  * `pr create`: Fix typo in documentation
  * `browse`: Do not use relative paths when `--repo` flag is
    used
* Wed Oct  4 2023 pdostal@suse.com
- Update to version 2.36.0:
  * update(run): Use attempt input when fetching jobs (#7831)
  * Bubble up return value from inner function calls in runEditItem
  * Update pkg/cmd/pr/create/create.go
  * pkg/cmd/root: fix startup panic (#8105)
  * Split clearing item, updating draft item and updating item values into individual functions for better readability; refactor field ID and project ID presence check into a separate function
  * Document clear flag in long form help as well
  * Add clear flag usage example
  * Move field value flag and clear flag exclusivity one level higher up to RunE
  * Use camelCase for fields
  * docs: update the details of fill and fill-first
  * Forward codespace ports over Dev Tunnels
  * Update triage.md
  * Support standard output format flags for secret and deploy-key list
  * docs: update the flag `--fill` docs
  * Show cancelled checks (#7960)
  * Return HTTP errors properly for some commands (#8037)
  * test: Add unit test for cache.ExportData
  * cache/delete: percent-encode keys
  * build(deps): bump mislav/bump-homebrew-formula-action from 2 to 3
  * Hint adding codespace scope to auth login (#7961)
  * Tests for the new clear flag
  * Driveby unrelated update: when both field ID and project ID are missing, specify that it's necessary to update the field value
  * Introduce clear flag on 'project item-edit' command to remove field value
  * feat(cache): Add JSON exporting support for cache list
* Wed Sep 20 2023 pdostal@suse.com
- Update to version 2.35.0:
  * Cleanup release create around new --notes-from-tag flag (#8016)
  * Document when gh auth login writes oauth token to plain text (#7781)
  * Show full permissions URL in `gh cs create` (#7983)
  * build(deps): bump goreleaser/goreleaser-action from 4 to 5
  * moved remoteTagExists under if NotesFromTag exists and added three tests
  * Clarify list repo behavior (#7964)
  * Reinforce not opening PRs without approval on an issue
  * Delete local tag when running `gh release delete --cleanup-tag` (#7884)
  * Add `--all` flag to `alias delete` command (#7900)
  * Move homebrew bump fork to personal repo
  * Revert "Add a test workflow for homebrew bump investigations (#7951)"
  * Add a test workflow for homebrew bump investigations (#7951)
  * Add `gh release create [<tag>] --notes-from-tag`
* Thu Sep  7 2023 pdostal@suse.com
- Update to version 2.34.0:
  * Use consistent variable naming
  * `gh status`: show status even if a comment 404s (#7873)
  * build(deps): bump actions/checkout from 3 to 4 (#7937)
  * rename template to mark-template cmd (#7923)
  * Simplify mock jobs response
  * Use "Link" header for pagination completion check
  * Fix pagination resp with "Link" header
  * Refactor GetJobs to use RESTWithNext
  * Add formula-path to homebrew-bump step (#7930)
  * Add JSON output flags to workflow list command (#7902)
  * fix tests
  * no other descriptions have a period
  * mark and unmark project as template
  * Add config clear-cache command (#7693)
  * Allow --disable-wiki flag with --template flag in repo create command (#7886)
  * Reword token invalid message (#7906)
  * 🐛 (repo create)execute clone when readme option is enabled (#7837)
  * Use go-gh prompter package (#7896)
  * pr checks return distinct exit code for PENDING checks (#7866)
  * Properly rename remote for GHES hosts (#7890)
  * Add verbose flag to api cmd (#7826)
  * Fix up Nix installation instructions (#7891)
  * Fetch all jobs on a gh view run --json
* Tue Aug 22 2023 pdostal@suse.com
- Update to version 2.33.0:
  * codespace: Handle HTTP request retry interruption (#7846)
  * linter appeasement
  * delete prompt package
  * prompter for milestone
  * prompter for projects
  * use prompter for labels
  * prompter for assignees
  * prompter for reviewers
  * use MultiSelect for metadata survey in pr, issue create
  * use prompter in shared editable code
  * linter appeasement
  * linter appeasement
  * prompter for milestone
  * prompter for projects
  * use prompter for labels
  * prompter for assignees
  * prompter for reviewers
  * use MultiSelect for metadata survey in pr, issue create
  * use prompter in shared editable code
  * use prompter in issue delete
  * use prompter in secret set
  * fix RegisterPassword
  * use new prompter in repo fork
  * switch to prompter in workflow commands
  * Upgrade to Go 1.21 (#7843)
  * Remove GHE handling for `workflow` scope (#7841)
  * Add clobber flag to `alias set` (#7787)
  * pass prompter around instead of opts
  * Add missing "ls" aliases to list commands (#7818)
  * Allow --org parameter in lieu of a repo context for rulesets, add current_user_can_bypass to rs view (#7747)
  * test for forking in org
  * strip more dead code
  * port more prompts and cover with new tests
  * remove dead code
  * finish porting existing tests
  * Codespaces: Use the host name from the logged in server for commands (#7795)
  * Update CONTRIBUTING.md
  * WIP porting repo edit to opts.Prompter
  * name MultiSelect parameters in interface
  * switch to Prompter.MultiSelect
  * Use filepath.Base to sanitize path for archive downloads (#7805)
  * `release create`: Trim spaces on interactive tag name input (#7759)
  * Do not allow issue and pr templates to be symlinks (#7756)
  * Allow deleting of local branch after merging cross repo PRs (#7709)
* Tue Jul 25 2023 pdostal@suse.com
- Update to version 2.32.1:
  * Use asciisanitization package from go-gh (#7745)
  * Do not make reviewer update request if there are no reviewer changes (#7730)
  * Fix pr checks command for GHES versions older than 3.9 (#7725)
  * Use filepath.Clean to sanitize path for archive downloads (#7720)
  * Sanitize file contents before displaying them (#7694)
  * Do not add auth token to redirect requests which do not have the same host as the inital request. (#7692)
* Wed Jul 12 2023 pdostal@suse.com
- Update to version 2.32.0:
  * add gh cache to Actions explainer
  * Clean up style nits and simplify some logic
  * fix typo
  * remove stray print
  * docs: example of setting multiple vars using stdin
  * Add --branch-repo flag
  * Add --verify-tag to release edit command (#7646)
  * make IDs cyan, add prompter test
  * Do not interpret "branch" placeholder in `api` command when `GH_REPO` is set (#7626)
  * Always show created gist privacy status. (#7645)
  * Use SmartBaseRepoFunc for api command (#7594)
  * Add check description to pr checks output (#7451)
  * fix pr create crash on interactive milestone selection
  * build(deps): bump google.golang.org/grpc from 1.49.0 to 1.53.0
  * split org/repo graphql queries, better tests
  * refactor graphql query a bit
  * add rs check tests
  * fix merge errors
  * misc cleanup
  * add ruleset check command
  * initial view tests
  * list test updates
  * update bypass response and parents logic, tests
  * update tests, add rules to view command
  * interactive ruleset selection, move shared logic
  * gracefully handle missing admin:org scope
  * don't allow both --repo and --org, add docs
  * split ruleset types by API type
  * allow getting parents, move list to shared package
  * basic ruleset view works
  * updates, initial list test
  * refactor and support org rulesets
  * GQL query works but it's messy
  * wip
  * start on rs list
  * start writing up structs for rules API payloads
  * WIP compute branch, call API
  * start on gh rs
  * build(deps): bump github.com/henvic/httpretty from 0.1.1 to 0.1.2 (#7657)
  * Rewrite issue develop command to fix numerous issues
  * Ensure gist edit request body matches desired schema (#7635)
  * Automatically fetch new branches created with issue develop (#7589)
  * Support --server-port behavior with conn details
  * Update httpretty to released version (#7654)
  * gh run cancel needs input validation
  * Add tenancy support (#7636)
  * Add title to iteration and milestone fields for projects (#7621)
  * Change how remotes are treated during `pr create` when repo is forked  (#7330)
  * Small tweaks to auth refresh remove-scopes and reset-scopes flags (#7631)
  * Don't deduplicate checks that stem from different events (#7618)
  * Add cli test to remove multiple scopes at once
  * Refactor as per review
  * Fix commit order
  * Add test for fill first flag
  * Add fill-first option to create pr
  * Add option to remove file from gist (#7560)
  * Remove old code paths and improve code comments for repo sync (#7610)
  * Early exit repo sync if merge-upstream requires workflow scope
  * Add remove/reset to auth refresh
  * typo
  * create cache commands
  * Return error on no-browser option if repo don't exists
* Thu Jun 22 2023 Martin Pluskal <mpluskal@suse.com>
- Remove obsolete constructs from spec file
* Thu Jun 22 2023 pdostal@suse.com
- Update to version 2.31.0:
  * Add timeouts to keyring operations (#7580)
  * Alphabetically sort labels for `pr/issue view` (#7587)
  * output URL on project commands (#7578)
  * refactor: nest if (#7596)
  * Fix alias import clobber flag (#7569)
  * Fix error handling for extension and shell alias commands (#7567)
  * chore: pkg imported more than once (#7591)
  * Added wantErrOut property
  * Speed up listing extensions by lazy-loading extension information when needed (#7493)
  * build(deps): bump github.com/AlecAivazis/survey/v2 from 2.3.6 to 2.3.7
  * Set upstream remote to track all branches after initial fetch (#7542)
  * api: output a single JSON array in REST pagination mode (#7190)
  * Introduce `gh project` commands (#7375)
  * fix tests
  * fix test
  * :nail_care: json export
  * fixed a type
  * Codespaces view command updates
  * build(deps): bump github.com/cli/go-gh/v2 from 2.0.0 to 2.0.1
  * Use homebrew fork in cli org and update token
  * Change site deployment ssh key to PAT
  * Resolve tests/lint errors
  * update gh auth status to write to stdout on success
  * Remove unused linter flag
  * Replace SurveyAskOne with Prompter
  * Add gist selector option to gist edit command
  * Improve docs around run rerun job flag (#7527)
  * Support viewing logs for jobs with composite actions
  * Fix bash completions for extensions and aliases
  * fix: Allow aliases to recognize extended commands (#7523)
  * force method to uppercase (#7514)
  * api: support array params in GET queries (#7513)
  * Fix flaky test
  * Remove unused type
  * Add test
  * Fix linting error
  * Don't display retention period if 0 days
  * Address comments
  * Update fields to show
  * Check if running in a codespace
  * Add gh cs view command
  * fix tests
  * Print empty line between file headers
  * :nail_care: improve code search output
  * incorporate code review feedback
  * remove empty line
  * change highlight color
  * adopt changes to User
  * implement code search
* Wed May 31 2023 pdostal@suse.com
- Update to version 2.30.0:
  * build(deps): bump github.com/stretchr/testify from 1.8.3 to 1.8.4
  * Do not generate docs for aliases (#7497)
  * Speed up gh start up time (#7487)
  * fix: apply latin matching filter to more fields
  * Allow creating of nested aliases (#7457)
  * fix variable name
  * Add cmd test for pr status with counts by state
  * Reorder Check and Status States enums variants alphabetically
  * Use go enums for status and check status graphql enums
  * Remove unused emptyIntrospectionFor test helper
  * Avoid setting status check rollups when user supplies fields
  * Rework state parsing for CheckRuns and StatusContexts
  * Split CheckRunState and StatusState parsing
  * Use two queries in one request for PR feature detection
  * go generate
  * switch to []int return for multiselect
  * Updated to sanitize asset filename prior to uploading. Fixes #7024
  * Remove unused prInstrospection fixture
  * Inject fake detector into PR status tests
  * Move CheckRunAndStatusContextCounts feature detection up stack
  * Use pseudo field for statusCheckRollupWithCountByState
  * build(deps): bump github.com/mattn/go-isatty from 0.0.18 to 0.0.19
  * Clarify docs regarding what is listed when running gh workflow list
  * Update browser package to avoid Windows crash
  * Update triage.md with severity descriptions
  * build(deps): bump github.com/stretchr/testify from 1.8.2 to 1.8.3
  * Implement initial spike for detecting and using counts by state
  * Short circuit status check GQL introspection for GitHub.com
  * Add support for detecting status and check counts in GQL
  * Implement parsing and counting of PR checks using new GQL fields
  * build(deps): bump github.com/stretchr/testify from 1.8.1 to 1.8.2
  * Remove old, unused detector fields (#7458)
  * Fix windows crash by bumping wincred
  * Avoid using named return in PR ChecksStatus
  * Add some comments to PR ChecksStatus
  * Add some further test coverage around PR ChecksStatus
  * Do not fall back to legacy template if template selector returns nil (#7444)
  * Mention setting GH_ENTERPRISE_TOKEN
  * survey: fix color contrast of default values in prompts (#7354)
  * respect GH_REPO env variable in `pr create`
  * Allow `gh repo set-default --view` without repo argument (#7441)
  * Introduce helpTopics type and reduce duplication across commands (#7414)
  * linter appeasement
  * use new prompter in run download
  * implement multi select support for prompter
  * delete PromptForRun
  * golf
  * use new prompter in run watch
  * use new prompter in run rerun
  * use new prompter in run cancel
  * use new prompter in run view
* Thu May 11 2023 pdostal@suse.com
- Update to version 2.29.0:
  * Fix label assets
  * Fix release guard for deployment workflow
  * Print message after codespace deletion (#7353)
  * Include auto-merge information in gh pr view (#7385)
  * Include auto-merge information in gh pr status (#7386)
  * Make: Fix target name for Windows platform (#7370)
  * New deployment workflow
  * Add progress labels for `gh release download` (#7380)
  * Add PR auto-merge status info to PR queries (#7384)
  * fix empty default description for local repository (#7383)
  * Add `alias import` command (#7118)
  * Fix shellcheck bugs in generate.sh (#7392)
  * Add capability to filter codespaces by repo owner (#7347)
  * Fix Makefile compatibility with macOS
* Tue Apr 25 2023 pdostal@suse.com
- Update to version 2.28.0:
  * New deployment workflow
  * Pretty-print JSON results of jq filtering (#7236)
  * gh: move `CODEOWNERS` inside the `.github/` dir (#7366)
  * feat: add visibility field (#7337)
  * Edit multiple issues, PRs in parallel (#7259)
  * add `--created` flag to `gh run ls` to filter listed runs by when they were created (#7352)
  * add `--event` flag to `gh run ls` to filter runs by their trigger
  * Diacritics substitution in prompt (#7205)
  * Correct some typos
  * Fix `gh cs ports` requiring `sudo` for privileged port numbers (#7326)
  * Initialize deployment.yml workflow file
  * Clarify how SSH keys are selected (#7325)
  * build(deps): bump github.com/cenkalti/backoff/v4 from 4.2.0 to 4.2.1
  * fix: normalize hostname for auth login (#6999)
  * Update go-gh to v2 (#7299)
  * Fix typo in `cs stop` command: `Stoppping` -> `Stopping` (#7318)
  * feat: add web flag for codespace list & create subcommand (#7288)
  * Enable owner flag to take multiple values for searching
  * Move completions generation from goreleaser to Makefile
  * Generate completion scripts for bundling in rpm and deb on release
  * Add `-R` as shorthand of `--repo` flag for search commands (#7274)
  * Fix invoker immediately closing
  * add "showing x of y organizations" header
  * Enhance ssh-key list to show signing ssh keys also
  * Add option to add ssh singing key
  * extend secure storage default to auth refresh
  * fix apparent typo
  * add --insecure-storage and make secure storage the default
  * fix: make number arg, commit arg, and flags mutually exclusive (#7268)
  * Additional help doc and example for auth setup-git (#7243)
  * docs: add commit SHA arg to gh browse help (#7267)
  * feat: add gh org list
  * move SSH key errors out of upload function
  * don't parse key bytes twice
  * lint fixes
  * cleanup
  * feat(run): add new delete command
  * Improve Amazon Linux install instructions
  * check SSH key existence before uploading
  * Fix typo in README.md
  * Autocomplete branch flags (#6031)
  * Resolve lint error
  * Specify branch to force exit code
  * Retry fetching repo from template
  * improve test resiliency
  * feat: allow filtering workflow runs by statuses
  * repo list: add test for invalid owner error
  * repo sync: clearer error message with actionable hint (#7110)
  * fix: throw error for non-existing org / repo with non-zero status in repo list (#7240)
  * refactor: use net/url JoinPath
  * refactor: set the default case first
  * fix: change MaximumNArgs from 2 to 1 in run view.go
  * Add `--template` flag for issue create and pr create (#7185)
  * Add a `--fail-fast` option to `pr checks --watch` (#7203)
  * docs: revise GH_CONFIG_DIR content in help_topic.go (#7230)
  * feat: add tests for attempt flag
  * feat: include attempt in getRunLog
  * refactor: don't show latest attempt
  * feat: append attempt number in returned run url
  * feat: pass latest attempt to RenderRunHeader for watch
  * feat: add attemptLabel to RenderRunHeader
  * feat: pass attempt to RenderRunHeader
  * feat: update GetRun path based on attempt
  * feat: pass 0 to fetch latest attempt
  * feat: add attempt flag to run view
  * refactor: revise errMsg in rename_test.go
  * refactor: remove unnecessary validations
  * refactor: use ExactArgs instead of MaximumNArgs
  * refactor: change from [] to {}
  * Properly handle closing files that have been writen to (#7199)
  * Bump github.com/mattn/go-isatty from 0.0.17 to 0.0.18 (#7217)
  * feat: gist rename test
  * variable: fix listing and deleting variables in an environment (#7207)
  * Support ext install --force (#7173)
  * use Prompter for `pkg/cmd/repo/archive` (#7083)
  * fix: revise test cases in TestNewCmdRename in rename_test.go
  * feat: add FlagErrorf for missing flag cases
  * feat: TestNewCmdRename for gist rename
  * refactor: remove unused code
  * Replace deprecated command with environment file
  * Skip checking keyring for token in certain scenarios (#7169)
  * feat: add gist rename logic
  * feat: add gistRenameCmd to gist.go
  * Added apt update command to linux install docs.
  * Bump actions/setup-go from 3 to 4 (#7177)
  * Fix multiword keyword quoting for search commands (#7170)
  * Fixes #455 - Hide "current branch" for pr status --repo
  * Tech debt cleanup for variable and secret commands (#7151)
  * Only replace control sequences (#7168)
  * Dont follow redirects on repo delete (#7106)
  * Add variable delete command (#6929)
  * Add variable list command (#6995)
  * Add variable set command (#6928)
  * Clarify `gh auth refresh` command behavior (#7132)
  * Make repo sync git fetch authenticated (#7139)
  * Improve documentation and consistency of the `--commit` flag for `gh browse` command (#7105)
  * Use transform.Transformer interface for ascii sanitization (#7117)
  * use t.Cleanup(m.Verify)
  * fix bug with Prompter.MultiSelect
  * new tooling for assertions about prompting
  * config get: support getting oauth_token from keyring
  * codespace ssh: fix "connection reset by peer"
  * Manually get current user name rather than use api client (#7114)
  * pr diff: sanitize control characters for terminal output
  * Bump github.com/gabriel-vasile/mimetype from 1.4.1 to 1.4.2
  * Make auth refresh more convenient with secure storage (#7098)
  * Fix delete tests
  * Match return style
  * Fix build errors
  * Properly handle C1 control sequences (#7079)
  * Introduce GH_PATH environment variable (#7025)
  * Use default host for auth token command if a hostname is not provided (#7094)
  * Always open new vscode window in `gh cs code` (#7092)
  * fix: correctly set `ErrNotOnAnyBranch` error in git client (#7082)
  * Standardize retry mechanism (#7027)
  * Update working-with-us.md
  * use new cfg.Authentication()
  * Include new line after existing fork error log (#7030)
  * Cleanup config.AuthToken and config.DefaultHost methods (#7049)
  * Add ability to store tokens in encrypted storage (#7043)
  * Refactor Config interface in preperation for encrypted token storage (#7033)
  * feat: add open num hash to browse command
  * Add `--repo` filter to more `gh codespaces` commands (#6669)
  * Update golang.org/x/net package (#7026)
  * Retry `git clone` on git clone failure in `gh repo fork --clone` (#6962)
  * use prompter for pkg/cmd/repo/unarchive
  * add command gh repo unarchive
  * Enable darwin arm64 builds in goreleaser (#4435)
  * Allow retrieving `projectItems` in JSON and allow adding/removing user owned projects (#7007)
  * Allow adding named gpg keys (#6993)
  * Adopt in delete.go
  * Rename f to run
  * Adopt in stop.go
  * Adopt in ssh.go
  * Adopt in ports.go
  * Adopt in list.go
  * Adopt in edit.go
  * Adopt in delete.go
  * Adopt in create.go
  * Move helper to iostreams
  * feat: add `--releases` option to `gh browse` (#6996)
  * Fix set-default interactive not showing all remotes (#6969)
  * Add visibility warning to repo edit (#6980)
  * Avoid implicitly fetching when adding a new git remote (#6990)
  * Teach gh cs create to use current repo as default (#6596)
  * Disallow update checker delaying the gh process (#6978)
  * Default to authenticated user on codespace delete (#6944)
  * Support Fork with Default Branch Only
  * Disable gh update checker in our precompiled binaries
  * GH_DEBUG: fix api logging not corrupting response bodies
  * secret set: enable multiline values when reading from .env file
  * Fix panic in ASCII sanitization (#6956)
  * Bump microsoft/setup-msbuild from 1.1.3 to 1.3.1
  * Fix adding/removing projects using flags for edit commands (#6955)
  * include readme viewing in small help
  * longer small help
  * Bump github.com/cli/oauth from 1.0.0 to 1.0.1
  * Sanitize ANSII control characters returned from the server (#6916)
  * Special case setting dependabot org secrets (#6941)
  * fix tests
  * WIP fixing tests
  * Change uint8 to uint64 to hold job with more than 255 run attempts (#6935)
  * Use int64 repository IDs for Codespaces user secrets
  * Fix ignoring ProjectsV2-specific errors for GHES
  * WIP: fixing tests
  * update doc
  * TODOs
  * clean up command screen
  * fix silencing git output
  * remove unused args from installGit
  * WIP on using pages
  * clean up some key handling
  * Rename `--confirm` flag to `--yes` for various destructive commands (#6915)
  * Fix race conditions in invoker_test (#6905)
  * Add `--reviewer` flag completion (#6873)
  * repo delete: change confirmation flag to `--yes` (#6911)
  * show token scopes on auth status (#6546)
  * Add notes about project scope to various commands (#6907)
  * Add `gh repo edit --enable-discussions` (#6903)
  * Bump the oauth library (#6885)
  * Fix flakey TestUpdateProjectV2Items (#6909)
  * extension create: make initial commit (#6833)
  * Warn against Windows absolute path when using `gh api` (#6895)
  * Codespaces create: Fix missing billable owner notice for individuals (#6891)
  * Linter and comment
  * Close port forward writer on reader
  * Add projectsV2 support to issue create, issue edit, pr create, and pr edit (#6735)
  * Use gRPC client to notify codespace of activity (#6870)
  * Fix `mergedBy` JSON export for PRs
  * Fix JSON payload for PR review author
  * repo set-default: support bare git repos
  * Use AuthToken function to retrieve AuthToken instead of GetOrDefault (#6878)
  * Migrate search commands to new table printer and add headers (#6869)
  * Add `search commits` command (#6817)
  * Use progress runner a few times
  * Add generic progress runner
  * Fix spinner on error
  * Start SSH server with gRPC
  * avoid panic when bad default given to Select
  * Rebuild container using gRPC client
  * link from readme
  * add intake document
  * Remove unused token field
  * Fix typo in has_uncommitted_changes for codespaces (#6812)
  * Address comments
  * Create `Invoker` object
  * Fix linting error and cleanup error messages
  * Create centralized Codespaces RPC invoker
  * Handle erase operation in auth git-credential command (#6805)
  * tweak selection
  * select base repo correctly when only one remote
  * Bump github.com/mattn/go-isatty from 0.0.16 to 0.0.17 (#6794)
  * docs: update codespace installation instructions (#6781)
  * Bump github.com/gdamore/tcell/v2 from 2.5.3 to 2.5.4
  * Fix fetching issue/PR comments
  * downgrade ubuntu to fix osslsigncode
  * Avoid sending empty JSON body when no params to api command (#6775)
  * Supported passing nested JSON arrays/objects to api command via fields (#6614)
  * Group PR, release, and repo subcommands
  * finish tests
  * WIP all but relocking
  * stub out rest of tests
  * todos
  * WIP tests
  * WIP on tests
  * Split issue commands into "General" vs. "Targeted"
  * further WIP
  * WIP on adding tests, add prompt, tweak things
  * Allow setting codespace display name during create (#6739)
  * wip: tweak output, update to Prompter, start on tests
  * error instead of prompt when no base repo + fixes
  * final bit of feedback
  * use factory git client
  * rename command and fix tests
  * tweak wording
  * Update git/client.go
  * WIP on single column support
  * Fix release assets upload retry logic
  * release create: clean up leftover draft release on upload/publish failure
  * Improve looking up draft releases by tag name
  * Fix API client code docs
  * freeze input when help active
  * use Pages to render help
  * these were bad
  * move help to its own window
  * Change alias list output format to YAML (#6603)
  * add more to usage
  * tweak UX and switch to prompter
  * tests pass
  * Fix clobbering old files in release download (#6694)
  * Bump goreleaser/goreleaser-action from 3 to 4
  * Flags instead of PersistentFlag
  * linter
  * Use -R for --repo shorthand and deprecate -r
  * Go 1.19: fix comment formatting for moq-generated mocks
  * bump golangci-lint
  * bump safeexec for 1.19 fix
  * Linter fixes (#6722)
  * Bump goreleaser
  * Update to Go 1.19
  * docs: Update installation instructions for WinGet (#6716)
  * port release command to prompter
  * Add `isDraft` to `search prs` json options, matching `pr view` (#6704)
  * export is_bot from issue list
  * export is_bot in issue/pr search
  * Add `--allow-update-branch` to the `repo edit` command
  * Use new domain for forwarded ports
  * Show version diff when updating a single extension (#6647)
  * Add support to exclude pre-releases from release list (#6625)
  * Prompt for owner when interactively creating repos (#6578)
  * Exclude the current user from reviewers when creating pr (#6464)
  * fix test
  * Document installing GitHub CLI in Codespaces
  * Expose commit OID in PR reviews JSON export
  * Bump mislav/bump-homebrew-formula-action from 1 to 2
  * Avoid duplicate remote tag lookups
  * Clarify --verify-tag flag description
  * Add --verify-tag flag for release creation command
  * Update go-gh to v1.0.0 (#6618)
  * Authenticate network git commands (#6541)
  * Fix up bindir for new version of goreleaser (#6621)
  * Set fetch depth for goreleaser to work properly
  * Fix commands that use iostreams RefreshScreen (#6607)
  * Update goreleaser so we can release ARM64 binaries for windows (#6605)
  * Revert "Fix `repo list` when belonging to org with IP Allow list enabled"
  * Use git client in extension manager (#6547)
  * Group issue commands into general vs. additional
  * go mod tidy
  * Fix SECURITY.md
  * Create SECURITY.md
  * Allow accessing Cobra built-in doc generation features
  * Remove the feedback section from gh help
  * Migrate to the new Cobra command grouping feature
  * Bump Cobra
  * use Prompter in pr merge
  * use Prompter in Commentable
  * use Prompter in template manager
  * use Prompter in pr create
  * Test reasonsMap construction
  * Implicitly return the nil value when no lock reason given
  * Alphabetize fields
  * Update comments
  * Remove direct calls to graphql library
  * Use strings.Cut
  * Backport strings.Cut
  * Refactor code to live inside default pkg
  * default lint fix
  * lint test update
  * fixing lint and formatting
  * Created more test cases, added in env section
  * beginning testing
  * deleted scratch pad of commit
  * thinking of a better solution, wip. BaseRepo() might be better split up
  * headed in the right direction. Needs tests and to be cleaned up. This is a working example of the teams design combined with https://github.com/cli/cli/pull/4859#issuecomment-1012776582
  * created `gh config base` a way to configure the base repo
  * Add failure icon
  * Restructured switch statement
  * Polished things
  * Polished error message
  * Use `if/else if` on error checking
  * Remove opts.PadlockState
  * Skip unlock api call if already unlocked
  * Remove opts.PadlockState
  * Refactor things
  * Modify documentation if called from issue or pr
  * Get graphql queries and mutations working
  * Rearrange
  * Add lock-related values to issue
  * Map parent commands to typenames
  * Export return values for Issue.Typename
  * Other changes
  * Added lock subcommands to pr command
  * Draft first design
  * Stub out files for lock command
  * Add author information in `pr list` JSON output
* Wed Apr  5 2023 Pavel Dostál <pdostal@suse.com>
- Update to 2.26.1
  https://github.com/cli/cli/releases/tag/v2.26.1
  What's Changed
  * extend secure storage default to auth refresh by @vilmibm in #7278
- Update to 2.26.1-pre0
  https://github.com/cli/cli/releases/tag/v2.26.1-pre0
  What's Changed
  * extend secure storage default to auth refresh by @vilmibm in #7278
- Update to 2.26.0
  https://github.com/cli/cli/releases/tag/v2.26.0
  Important: credentials now stored securely by default
    When running gh auth login, your credentials will now be stored in your operating system's
    credential storage instead of directly on disk. In other words, --secure-storage is now default
    behavior. We've added a new flag, --insecure-storage, to opt into the old insecure behavior in
    case you need to debug an issue with credential storage.
    As before, to take advantage of credential storage, please re-run gh auth login.
    For more context, you can read the v2.24.0 release notes
    Ref: secure storage by default by @vilmibm in #7276
  Other new features
  * Allow filtering workflow runs by status by @alex-petrov-vt in #7249
  * Gist rename by @wingkwong in #7212
  * Add a --fail-fast option to pr checks --watch by @benjlevesque in #7203
  * Add --template for issue and PR by @guerinoni in #7185
  * gh run view --attempt by @wingkwong in #7232
  * utocomplete branch flags by @bchadwic in #6031
  Bugfixes
  * Make number arg, commit arg, and flags mutually exclusive by @kkocha in #7268
  * Check SSH key existence before uploading by @vaindil in #7246
  * Throw error for non-existing org / repo with non-zero status in repo list by @wingkwong in #7240
  Docs and development changes
  * Bump github.com/mattn/go-isatty from 0.0.17 to 0.0.18 by @dependabot in #7217
  * Properly handle closing files that have been writen to by @samcoe in #7199
  * Added apt update command to linux install docs. by @srgk26 in #7186
  * Revise GH_CONFIG_DIR content in help_topic.go by @wingkwong in #7230
  * Refine the Makefile file so that it can do the basic work by @cubxxw in #7228
  * Clearer message with actionable hint for repo sync by @macmacbr in #7110
  * Fix typo in README.md by @SonicGDX in #7244
  * Retry fetching repo from template by @heaths in #7080
  * Repo list: add test for invalid owner error by @mislav in #7241
  * Improve Amazon Linux install instructions by @mislav in #7252
  * Add commit SHA arg to gh browse help by @kkocha in #7267
  * Additional help doc and example for auth setup-git by @kkocha in #7243
- Update to 2.26.0-pre0
  https://github.com/cli/cli/releases/tag/v2.26.0-pre0
  What's Changed
  * Bump github.com/mattn/go-isatty from 0.0.17 to 0.0.18 by @dependabot in #7217
  * Properly handle closing files that have been writen to by @samcoe in #7199
  * feat: gist rename by @wingkwong in #7212
  * Added apt update command to linux install docs. by @srgk26 in #7186
  * docs: revise GH_CONFIG_DIR content in help_topic.go by @wingkwong in #7230
  * add a --fail-fast option to pr checks --watch by @benjlevesque in #7203
  * Add --template for issue and PR by @guerinoni in #7185
  * Feature(Fixes #7229) : Refine the Makefile file so that it can do the basic work by @cubxxw in #7228
  * feat: gh run view --attempt by @wingkwong in #7232
  * fix: throw error for non-existing org / repo with non-zero status in repo list by @wingkwong in #7240
  * issue-6910 clearer message with actionable hint for repo sync by @macmacbr in #7110
  * Autocomplete branch flags by @bchadwic in #6031
  * Fix typo in README.md by @SonicGDX in #7244
  * Retry fetching repo from template by @heaths in #7080
  * repo list: add test for invalid owner error by @mislav in #7241
  * feat: allow filtering workflow runs by status by @alex-petrov-vt in #7249
  * Improve Amazon Linux install instructions by @mislav in #7252
  * Check SSH key existence before uploading by @vaindil in #7246
  * docs: add commit SHA arg to gh browse help by @kkocha in #7267
  * Additional help doc and example for auth setup-git by @kkocha in #7243
  * fix: make number arg, commit arg, and flags mutually exclusive by @kkocha in #7268
  * secure storage by default by @vilmibm in #7276
* Wed Mar 22 2023 Pavel Dostál <pdostal@suse.com>
- Update to 2.25.1
  https://github.com/cli/cli/releases/tag/v2.25.1
  What's Changed
  * variable list: fix api path by @rsteube in #7207
* Tue Mar 21 2023 Pavel Dostál <pdostal@suse.com>
- Update to 2.25.0
  https://github.com/cli/cli/releases/tag/v2.25.0
  What's New
  * New suit of commands for working with Repository and Organization variables
  - variable set by @atirikt in #6928
  - variable list by @atirikt in #6995
  - variable delete by @atirikt in #6929
  * ext install: Introduce new --force flag by @heaths in #7173
  What's Changed
  * browse: Improve documentation and consistency of the --commit flag by @alex-petrov-vt in #7105
  * repo sync: Ensure git fetch is always authenticated by @samcoe in #7139
  * repo delete: Don't delete repos that have transfered ownership by @samcoe in #7106
  * auth: Skip searching keyring when checking for environment tokens by @benjlevesque in #7169
  * auth refresh: Improve documentation of --scopes flag behavior by @alex-petrov-vt in #7132
  * pr status: Hide "current branch" when using --repo flag by @jtpetty in #7180
  * repo archive: Change to use Prompter package by @Ruminateer in #7083
  * search: Fix multiword keyword quoting by @samcoe in #7170
  * Replace deprecated command with environment file by @jongwooo in #7195
  * New prompt testing utility by @vilmibm in #7116
  * Use transform.Transformer interface for ascii sanitization by @samcoe in #7117
  * Only replace control sequences by @samcoe in #7168
  * Tech debt cleanup for variable and secret commands by @samcoe in #7151
  * Bump actions/setup-go from 3 to 4 by @dependabot in #7177
- Update to 2.25.0-pre0
  https://github.com/cli/cli/releases/tag/v2.25.0-pre0
  What's New
  * New suit of commands for working with Repository and Organization variables
  * variable set by @atirikt in #6928
  * variable list by @atirikt in #6995
  * variable delete by @atirikt in #6929
  * ext install: Introduce new --force flag by @heaths in #7173
  What's Changed
  * browse: Improve documentation and consistency of the --commit flag by @alex-petrov-vt in #7105
  * repo sync: Ensure git fetch is always authenticated by @samcoe in #7139
  * repo delete: Don't delete repos that have transfered ownership by @samcoe in #7106
  * auth: Skip searching keyring when checking for environment tokens by @benjlevesque in #7169
  * auth refresh: Improve documentation of --scopes flag behavior by @alex-petrov-vt in #7132
  * pr status: Hide "current branch" when using --repo flag by @jtpetty in #7180
  * repo archive: Change to use Prompter package by @Ruminateer in #7083
  * search: Fix multiword keyword quoting by @samcoe in #7170
  * Replace deprecated command with environment file by @jongwooo in #7195
  * New prompt testing utility by @vilmibm in #7116
  * Use transform.Transformer interface for ascii sanitization by @samcoe in #7117
  * Only replace control sequences by @samcoe in #7168
  * Tech debt cleanup for variable and secret commands by @samcoe in #7151
  * Bump actions/setup-go from 3 to 4 by @dependabot in #7177
* Thu Mar  9 2023 Pavel Dostál <pdostal@suse.com>
- Update to 2.24.2
  https://github.com/cli/cli/releases/tag/v2.24.1
  What's Changed
  * codespace ssh: fix "connection reset by peer" by @mislav in #7120
* Thu Mar  9 2023 Pavel Dostál <pdostal@suse.com>
- Update to 2.24.1
  https://github.com/cli/cli/releases/tag/v2.24.1
  What's Changed
  * Fix progress indicator bug with generic RunWithProgress function by @jungaretti in #6848
  * auth login: Fix retrieving current login name when pasting auth token @samcoe in #7114
- Update to 2.24.0
  https://github.com/cli/cli/releases/tag/v2.24.0
  What's Changed
  * repo fork: retry git clone on git clone failure by @jsoref in #6962
  * repo fork: add newline after printing error about existing fork by @digitalfu in #7030
  * codespace: add --repo filter to more commands by @cmbrose in #6669
  * codespace code: always open new VS Code window by @cmbrose in #7092
  * pr diff: sanitize control characters for terminal output by @mislav in #7108
  * browse: use --commit flag to browse commit SHAs containing only digits by @yanskun in #7038
  * pr status: fix when on a detached HEAD by @alex-petrov-vt in #7082
  * auth token: respect GH_HOST if a hostname is not provided by @samcoe in #7094
  * Address Projects bugs by @samcoe in #7007
  * Properly handle C1 control sequences by @samcoe in #7079
  * Cleanup logic to retry on failure by @samcoe in #7027
  * Cleanup config.AuthToken and config.DefaultHost methods by @samcoe in #7049
  * Bump golang.org/x/net package by @samcoe in #7026
  * Bump github.com/gabriel-vasile/mimetype from 1.4.1 to 1.4.2 by @dependabot in #7107
  * Update working-with-us.md by @vilmibm in #7077
  What's New
  * Option to store gh access token in system encrypted storage
    The gh auth login and gh auth refresh commands gained the new --secure-storage flag.
    In this mode, the access token that GitHub CLI uses for GitHub API requests will now
    be stored in the system keyring instead of in the plain text config file.
    To migrate as an existing GitHub CLI user, re-authenticate like so:
    gh auth refresh --secure-storage -h github.com
    Depending on your system, you could get an interactive prompt to allow the CLI tool to access the system keyring. The systems that are supported are:
  * Keychain on macOS
  * GNOME Keyring on Linux (Secret Service dbus interface)
  * Wincred on Windows
    Please note:
    This feature is currently opt-in, but will become the default in the near future.
    If none of the system storage providers are found, or the store operation fails,
    the token will be written to the config file as before.
    Using this feature could result in Go extensions breaking if they were not updated to the latest go-gh version. If extensions you are using no longer work after migrating your token to secure token storage, please report the issue to that extension's repository.
    Storing tokens in system keyring most likely won't work in “headless” environments.
  Other additions
  * Add option to store credentials in OS keyring by @samcoe @mislav in #7033 #7043 #7098
  * browse: add --releases option by @owenvoke in #6996
  * Add gpg-key add --title to name GPG keys by @rpadaki in #6993
  * Add command gh repo unarchive by @Ruminateer in #7003
  * Add macOS arm64 prebuilt binaries by @beret in #4435
  * Introduce GH_PATH environment variable by @samcoe in #7025
* Wed Feb  8 2023 Pavel Dostál <pdostal@suse.com>
- Update to 2.23.0
  https://github.com/cli/cli/releases/tag/v2.23.0
  What's New
  * repo fork: Add --default-branch-only flag by @jsoref in #6983
  * repo edit: Add visibility warning by @tuananhlai and @samcoe in #6980
  What's Changed
  * secret set: Fix setting Codespaces user secrets by @joshmgross in #6923
  * secret set: Fix setting Dependabot org secrets by @samcoe in #6941
  * secret set: Fix multiline values when reading from .env file by @mislav in #6932
  * run: Fix integer overflow error when more than 255 run attempts by @samcoe in #6935
  * extension browse: Improve usability and accessibility by @vilmibm in #6584
  * issue/pr edit: Fix adding/removing projects using flags by @samcoe in #6955
  * codespace delete: Default to authenticated user by @luanzeba in #6944
  * codespace create: Default to using current repo by @rneatherway in #6596
  * repo set-default: Fix interactive mode not showing all remotes by @despreston in #6969
  * GH_DEBUG: Fix API logging corrupting response bodies by @mislav in #6976
  * Avoid implicitly fetching when adding a new git remote by @mislav in #6990
  * Sanitize ANSII control characters returned from the server by @samcoe in #6916, #6956
  * Disable gh update checker in our precompiled binaries by @mislav in #6977
  * Disallow update checker delaying the gh process by @mislav in #6978
  * Bump github.com/cli/oauth from 1.0.0 to 1.0.1 by @dependabot in #6948
  * Bump microsoft/setup-msbuild from 1.1.3 to 1.3.1 by @dependabot in #6973
* Mon Jan 30 2023 Pavel Dostál <pdostal@suse.com>
- Update to 2.22.1
  https://github.com/cli/cli/releases/tag/v2.22.1
  * Fix gh issue edit and gh pr edit for GitHub Enterprise Server by @mislav in #6921
  * Add --reviewer flag completion by @benjlevesque in #6873
  * Rename --confirm flag to --yes for various destructive commands by @damiensedgwick in #6915
  * Fix race conditions in invoker_test by @cmbrose in #6905
* Thu Jan 26 2023 Pavel Dostál <pdostal@suse.com>
- Update to 2.22.0
  https://github.com/cli/cli/releases/tag/v2.22.0
  * Fix typo in has_uncommitted_changes for codespaces by @jkeech in #6812
  * Create centralized Codespaces RPC invoker by @dmgardiner25 in #6657
  * avoid panic when bad default given to Select by @vilmibm in #6831
  * Rebuild container using gRPC client by @dmgardiner25 in #6830
  * Start SSH server with gRPC client by @dmgardiner25 in #6838
  * Add search commits command by @kevhlee in #6817
  * Migrate search commands to new table printer and add headers by @samcoe in #6869
  * Use AuthToken function to retrieve AuthToken instead of GetOrDefault by @samcoe in #6878
  * Use gRPC client to notify codespace of activity by @dmgardiner25 in #6870
  * intake doc by @vilmibm in #6815
  * Fix JSON payloads for PR reviewers, mergedBy by @mislav in #6881
  * repo set-default: support bare git repos by @mislav in #6880
  * Continue projectsv2 support by @qoega in #6735
  * Codespaces create: Fix missing billable owner notice for individuals by @RyanJamesCaldwell in #6891
  * Half close port forwarding connections to fix hangs by @cmbrose in #6888
  * Warn against Windows absolute path when using gh api by @kevhlee in #6895
  * make a commit on extension create by @mntlty in #6833
  * Fix flakey TestUpdateProjectV2Items by @mislav in #6909
  * Bump the oauth library by @mislav in #6885
  * Add gh repo edit --enable-discussions by @azu in #6903
  * Add notes about project scope to various commands by @samcoe in #6907
  * show token scopes on auth status by @mntlty in #6546
  * repo delete: change confirmation flag to --yes by @damiensedgwick in #6911
* Wed Jan  4 2023 Pavel Dostál <pdostal@suse.com>
- Update to 2.21.2
  https://github.com/cli/cli/releases
  * docs: update codespace installation instructions by @levenleven in #6781
  * Bump github.com/mattn/go-isatty from 0.0.16 to 0.0.17 by @dependabot in #6794
  * Bump github.com/gdamore/tcell/v2 from 2.5.3 to 2.5.4 by @dependabot in #6798
  * Handle erase operation in auth git-credential command by @samcoe in #6805
  * select base repo correctly when only one remote by @vilmibm in #6803
* Tue Nov 29 2022 Emily Roberts <nopeinomicon@posteo.net>
- Update to 2.20.2
  https://github.com/cli/cli/releases
  * Update security policy by @maclarel in #6587
  * Fix listing repositories for a named GitHub user by @mislav in #6608
  * Fix commands not properly refreshing the terminal screen by @samcoe in #6607
* Fri Nov 11 2022 chris@computersalat.de
- Update to 2.20.0
  https://github.com/cli/cli/releases
* Wed Sep  7 2022 kastl@b1-systems.de
- Update to version 2.14.2:
  * Remove accidental caching from `repo list` and other commands
  * strip whitespace when adding topics
  * Set blank headers so they are not automatically resolved by go-gh (#5935)
  * Post go-gh integration cleanup (#5933)
* Wed Jul 13 2022 chris@computersalat.de
- Update to 2.14.1
  https://github.com/cli/cli/releases
  * What's Changed
  - auth login/refresh: Fix auth token not being present in login and refresh flows @samcoe in #5928
- fix spec
  * add missing Group
* Mon Jul 11 2022 chris@computersalat.de
- Update to 2.13.0
  https://github.com/cli/cli/releases
  * What's New
  - Add pr merge --match-head-commit flag by @ffalor in #5692
  - Add codespace create --retention-period flag by @gdomingu in #5825
  - Add codespace list/stop/delete --org management capabilities for organization administrators by @greggroth and @8Gitbrix in #5807 #5812 #5827
  - codespace ssh: automatically generate SSH keys by @cmbrose in #5752
  - codespace create: notify user when codespace usage is covered by an organization by @jshorty in #5816
  - secret set: allow setting Codespace repository secrets by @greggroth in #5802
  - Add Windows ARM precompiled binary and support arm64 extensions by @azchohfi in #5715
  * What's Changed
  - Improve gh auth help message based on CI environment by @spenserblack in #5781
  - Fix determining the path to the gh executable under Homebrew by @mislav in #5822
  - pr create: clear filter when selecting from a list in interactive mode by @wilhelmeek in #5841
  - repo fork: raise error if attempting to fork own repository by @jf-delineate in #5794
  - Simplify codespace picker by @greggroth in #5826
  - Bump github.com/stretchr/testify from 1.7.3 to 1.7.4 by @dependabot in #5833
* Thu May 26 2022 stimut@gmail.com
- Update to version 2.11.3:
  * Bugfix: Retention period is being sent to the API as 0 (#5706)
  * Fix Cobra completion output going to stdout
  * Fix --version flag printing to stdout
  * Add --upstream-remote-name flag to gh replo clone (#5619)
  * Parallelize `label clone` (#5687)
  * Stop bumping winget manifest as part of release automation (#5699)
  * Write Cobra deprecation messages to stderr
  * Bump goreleaser/goreleaser-action from 2 to 3
  * Clarify that ShowResponseHeaders includes status line
  * Fix owner qualifier for search queries (#5693)
  * Add `--pattern` field to `run download` (#5539)
  * add `include-all-branches` flag to `repo create` (#5537)
  * Add ability to set title for ssh key in auth login (#5524)
  * Always clear screen when watching PR checks (#5678)
  * Fix `label clone` to pass orderBy (#5675)
  * pr create: ensure clear error when `--body` is missing in nonTTY mode
  * Allow passing full extension name (#5464)
  * Fixing #5624 - Removing unneeded hint and additional new line (#5642)
  * Extract feature detection package (#5494)
  * dont need assignment
  * issue view: ensure loading indicator is stopped when a prompt is shown (#5641)
  * Change int to uint64 for large fields (#5651)
  * filter out internal ports from gh cs ports list
  * Support rerunning Actions runs with debug logging (#5594)
  * Allow nil to truncate template function
  * Support and favor delete for secrets (#5617)
  * Fix whitespace in search prs examples (#5650)
  * Fix struct field tag (#5649)
  * Replace uses of strings.Title (#5623)
  * Removing confusing user search text (#5620)
  * Re-enable linters now that golangci-lint has been updated (#5615)
* Wed May 11 2022 rombert@apache.org
- Update to version 2.10.1:
  * Hide retention-period flag (#5607)
  * Merge pull request #5504 from greggroth/gregg/retention-period
  * repo clone: document the upstream remote (#5466)
  * auth: respect GH_BROWSER, `browser` config, avoid opening non-HTTP URLs
  * repo list: add `--visibility internal` filter (#5564)
  * Fix nil pointer exception in codespace selection
  * add devcontainer (#5592)
  * Ensure stable presentation of FORBIDDEN errors
  * :nail_care: optimize fetches
  * Ignore FORBIDDEN errors for `gh status`
  * status: exclude results from archived repositories
  * Add `exclude-drafts` flag to `gh release list`
  * Upgrade to go 1.18 (#5542)
  * Update order
  * Handle star in display name
  * Dis-ambiguate "currentBranch"
  * :nail_care:
  * Add `--json` support to `label list` (#5567)
  * Add Display Name to the list command
  * Remove empty return
  * Fix non-working `gh issue view` usage example (#5563)
  * Fix: 5501 - Added examples of negated qualifiers to search commands (#5562)
  * Add label list sorting and delete command (#5503)
  * Add the ability to pass teams to `review-requested` (#5538)
  * Document linux distribution updating  (#5531)
  * Consistent version format in version upgrade notice
  * Fix grammar in `repo create` prompt (#5557)
  * issue comment: support quotes and arguments in EDITOR value
  * Remove mention of function
  * Use named return values
  * Use safeClose instead of Close
  * Update auth error message
  * Remove `Stringer` from `ghrepo.Interface` (#5536)
  * Bump github.com/google/go-cmp from 0.5.7 to 0.5.8 (#5533)
  * Add progress indicator to `gist create` (#5526)
  * Clarify `label edit --name` switch (#5525)
  * Bump github.com/cpuguy83/go-md2man/v2 from 2.0.1 to 2.0.2
  * Add autocomplete descriptions for aliases and extensions (#5447)
  * Replace ioutil with io and os (#5498)
  * Add `label edit` command (#5519)
  * Properly handle issue and pr state options when building search queries (#5513)
  * Add `label clone` command (#5452)
  * Don't error on list commands when no results found (#5479)
  * refactor merge command
  * Bump github/codeql-action from 1 to 2
  * Avoid crash when deleting gist with no owner
  * Add context to errors
  * Resolve feedback
  * Remove function return
  * PR feedback
  * Fix displayed header for search prs command (#5488)
  * add ls alias to gh repo list (#5480)
  * Clarify session helper
  * Clean up more errors
  * Clean up errors
  * Fix -c option
  * Print JupyterLab URL
  * Fix name of RPC service
  * Clean up Jupyter code
  * Fix tests
  * Final copy and behavior update for prompt
  * go fmt
  * Change the way we parse list-devcontainers response
  * Fix tests
  * Change some copy per product's suggestions
  * Refactor liveshare setup to a new function
  * Clean up code
  * Fix RPC call
  * Add cs jupyter
  * Rename test
  * Add interactive prompt to choose from list of available devcontainer files
  * Add devcontainer_path API param as an option
* Thu Mar 10 2022 chris@computersalat.de
- Update to 2.5.2
  https://github.com/cli/cli/releases
  * Other Bugfixes
  - Fix HexToRGB panic by @markphelps in #5247
  * Other Changes
  - Support filtering PRs authored by GitHub Apps by @joshmgross in #5180
  - gh auth login: added flags to partially automate flow by @jonathan-enf in #5158
  - Codespaces Create: Allow Accepting Permissions by @markphelps in #5234
  * Development & Docs
  - Bump github.com/itchyny/gojq from 0.12.6 to 0.12.7 by @dependabot in #5263
  - Misc. docs improvements by @mislav in #5223
  - Use StringEnumFlag helper in more places by @mislav in #5221
  - Change how gh-cli is installed on fedora by @Hanjingxue-Boling in #5204
- updated vendor.tar.gz
* Thu Feb 17 2022 <chris@computersalat.de>
- Update to 2.5.1
  https://github.com/cli/cli/releases
  * New features
  - Add display name to codespaces prompts and JSON output by @veverkap in #5044
  - Add pr checks --watch flag by @endorama in #4519
  * Fixes
  - auth login --with-token: fix authenticating git operations by @mislav in #5186
  - release create: respect discussion category when creating a release with assets by @k-jun in #5019
  - gist create: handle Windows-style file paths by @joshmgross in #5173
  - release create: warn about unpushed local git tag by @samcoe in #5104
  - Ignore EPIPE errors when writing to a closed pager by @mislav in #5143
  - Rotate our Windows code-signing certificates by @mislav in #5196
- updated vendor.tar.gz
* Tue Dec 28 2021 Emily Roberts <nopeinomicon@posteo.net>
- Update to version 2.4.0
  - Add repo edit command by @g14a in gh#cli/cli#4318
  - release create: add --generate-notes functionality by @Sixeight in gh#cli/cli#4467
  - release create: add interactive mode to choose a tag name by @sguzmanm in gh#cli/cli#4525
  - pr merge: allow editing commit subject by @cristiand391 in gh#cli/cli#3344
  - secret set: allow importing secrets from a dotenv file by @lpessoa in gh#cli/cli#4534
  - run list/view: add --json export functionality by @cristiand391 in gh#cli/cli#3869
  - Refresh man pages by @mislav in gh#cli/cli#4939
  - Add installation instructions for pkgsrc by @bsiegert in gh#cli/cli#4931
  - pr view: ensure that PR reviews are always rendered in --comments mode by @mislav in gh#cli/cli#4848
  - api: handle HTTP 409 error message from the server by @mislav in gh#cli/cli#4862
  - issue edit: fix race condition when updating labels by @despreston in gh#cli/cli#4861
  - browse: support --commit with the repo override flag by @bchadwic in gh#cli/cli#4845
  - repo create: fix printing repo URL in no-TTY mode by @mislav in gh#cli/cli#4904
  - repo sync: use the new merge-upstream API if available by @mislav in gh#cli/cli#4942
  - run: display and treat "Cancelled" status as a failure by @bchadwic in gh#cli/cli#4850
  - extension upgrade: an already up-to-date extension should not a produce a failure by @tisonkun in gh#cli/cli#4857
  - Avoid showing non-open PRs as related to the default branch by @AyushRawal in gh#cli/cli#4285
  - git remotes: fix treating ssh.github.com as a github.com host by @mislav in gh#cli/cli#4938
  - Bump Cobra to 1.3.0 for improved completion support by @mislav in gh#cli/cli#4936
  - Bump spinner to 1.18.0 by @mislav in gh#cli/cli#4937
* Mon Dec 20 2021 Emily Roberts <nopeinomicon@posteo.net>
- Change issue references in the changelog to proper OBS abbreviations
* Sat Dec 18 2021 Emily Roberts <nopeinomicon@posteo.net>
- Update to version 2.3.0
  * Add support for precompiled extensions
  - fix binary extensions on windows by @vilmibm in gh#cli/cli#4717
  - binary extension migration by @vilmibm in gh#cli/cli#4588
  - make extension create binary aware by @vilmibm in gh#cli/cli#4718
  - Extensions create nail_care by @mislav in gh#cli/cli#4802
  * rewrite gh repo create by @meiji163 @pxrth9 in gh#cli/cli#4578
  - gh repo create will no longer automatically add a git remote to the local git repository in the current directory. To emulate old behavior when inside a local git repository, use gh pr create --source ..
  - gh repo create will only prompt interactively when run with no arguments. Otherwise, all arguments should be passed explicitly.
  * Fix codespace code command under WSL by @mislav in gh#cli/cli#4747
  * Inherit API endpoint configuration from the Codespaces environment by @marwan-at-work in gh#cli/cli#4723
  * Remove the default value from idle-timeout by @reybard in gh#cli/cli#4756
  * Support listing and removing user Codespaces secrets by @joshmgross in gh#cli/cli#4714
  * Support setting user Codespaces secrets by @joshmgross in gh#cli/cli#4699
  * Add idle_timeout_minutes as possible cs create param by @reybard in gh#cli/cli#4741
  * Adds a timeout context to the ssh waiter to prevent indefinite hanging by @reybard in gh#cli/cli#4635
  * Rename errors from Live Share to generic codespace by @josebalius in gh#cli/cli#4705
  * Add prebuild availability status to create codespaces by @adnamalin in gh#cli/cli#4737
  * Add command gh auth setup-git for setting up gh-cli as git cred helper by @despreston in gh#cli/cli#4246
  * Add gh config list by @meiji163 in gh#cli/cli#4729
  * Add new flag gh secret set --no-store to print the encoded secret by @sguzmanm in gh#cli/cli#4423
  * Adding release download for.zip and .tar.gz archives by @lpessoa in gh#cli/cli#4489
  * gh repo rename by @pxrth9 in gh#cli/cli#4450
  * Ignore scope suggestions for http 422 by @despreston in gh#cli/cli#4809
  * pr diff color output fixes by @mislav in gh#cli/cli#4833
  * PR merge should, after switching branches, pull by @pxrth9 in gh#cli/cli#4748
  * Don't swallow duplicate SSH key error by @despreston in gh#cli/cli#4807
  * gh pr merge fails to delete remote branch if $PWD is not a git repository by @pxrth9 in gh#cli/cli#4769
  * Fix up bug in RemoveEntry and add tests for config_map by @samcoe in gh#cli/cli#4784
  * Escape workflow information when generating URLs by @samcoe in gh#cli/cli#4760
  * Confirm name change before creating a repo with special characters by @bchadwic in gh#cli/cli#4562
  * encode gh browse output URL by @bchadwic in gh#cli/cli#4663
  * add base repo resolution to gh repo archive by @meiji163 in gh#cli/cli#4654
  * add base repo resolution to gh repo delete by @meiji163 in gh#cli/cli#4655
  * Fix stack overflow in AddJSONFlags by @rsteube in gh#cli/cli#4614
  * Fix rendering issue in "formatting" help topic by @pbnj in gh#cli/cli#4661
  * fix branch flag on browse within dir by @bstncartwright in gh#cli/cli#4676
  * Generate Go 1.17-style go:build directives by @mislav in gh#cli/cli#4838
  * Bump github.com/itchyny/gojq from 0.12.5 to 0.12.6 by @dependabot in gh#cli/cli#4832
  * some automation by @vilmibm in gh#cli/cli#4810
  * Improve issue view re: overfetching, PR support by @mislav in gh#cli/cli#4803
  * Improve queries in issue commands: no overfetching, support PR arguments by @mislav in gh#cli/cli#4794
  * Bump github.com/mattn/go-colorable from 0.1.11 to 0.1.12 by @dependabot in gh#cli/cli#4804
  * Replace shurcool/graphql with cli/shurcool-graphql by @samcoe in gh#cli/cli#4750
  * update help for magic type conversion gh#cli/cli#4365 by @signalwerk in gh#cli/cli#4434
  * fix angle brackets in man pages by @meiji163 in gh#cli/cli#4752
  * Overhaul manual pages for the web by @mislav in gh#cli/cli#4675
  * Fix CODEOWNERS for codespaces by @mislav in gh#cli/cli#4728
  * Don't use gpg in Debian instruction by @TobiX in gh#cli/cli#4610
  * Bump bluemonday to silence the security alert by @mislav in gh#cli/cli#4607
- Changes from 2.2.0
  * Support for GitHub Codespaces
  * Add repo delete command by @meiji163 in gh#cli/cli#4451
  * Add run cancel command by @cristiand391 in gh#cli/cli#3833
  * Add gpg-key management commands by @owenvoke in gh#cli/cli#3822
  * Support logging in to github.localhost by @joshmgross in gh#cli/cli#4523
  * browse: respect the current working directory for file arguments by @bchadwic in gh#cli/cli#4007
  * release create: respect the --draft flag in interactive mode by @Sixeight in gh#cli/cli#4542
  * api: avoid repeating GET parameters when paginating by @mislav in gh#cli/cli#4559
  * The progress spinner is now visible against a light background gh#cli/cli#4556
  * Dispatch binary extensions directly by @vilmibm in gh#cli/cli#4568
  * Fix copy/paste mistake in docs by @stdtom in gh#cli/cli#4582
- Changes from 2.1.0
  * Add repo archive command by @pxrth9 & @meiji163 in gh#cli/cli#4410
  * Add support for precompiled extensions by @vilmibm in gh#cli/cli#4308 gh#cli/cli#4373
  * If an extension repository publishes Releases with uploaded binary assets named with a suffix formatted like {OS}-{ARCH} (e.g. linux-amd64), the matching binary will be downloaded and installed as the extension instead of cloning the code from the extension repository.
  * pr list: add --draft, --non-draft, and --head filters by @SiarheiFedartsou in gh#cli/cli#4316 gh#cli/cli#4279
  * pr diff: add --patch flag by @m4ver1k in gh#cli/cli#4460
  * browse: add --commit flag to open the permalink for the latest commit by @bchadwic in gh#cli/cli#3950
  * api: add docs hint on how to use use stdin by @rethab in gh#cli/cli#4291
  * pr checks/run: revised "pending" and "skipped" symbols by @bchadwic in gh#cli/cli#4090
  * pr checkout: also set pushRemote for new branches by @RasmusWL in gh#cli/cli#4363
  * extension list: speed up checking for updates by @samcoe in gh#cli/cli#4396
  * extension install: document installing using a full URL by @wrslatz in gh#cli/cli#4271
  * extension create: use /usr/bin/env bash instead of /bin/bash in generated shebang by @kidonng in gh#cli/cli#4203
  * browse: add support for line ranges browse by @despreston in gh#cli/cli#4253
  * browse: fix markdown files with line ranges by @andrewhsu in gh#cli/cli#4310
  * repo garden: use the x/term package instead of shelling out to stty by @mislav in gh#cli/cli#4214
  * repo sync: allow user input for git fetch by @samcoe in gh#cli/cli#4328
  * repo create: avoid swallowing error from a prompt by @mislav in gh#cli/cli#4331
  * Skip authentication requirement for internal completion commands by @cuonglm in gh#cli/cli#4189
  * Add quotes around @me in documentation to ensure examples work in PowerShell by @Jernik in gh#cli/cli#4239
  * Suggest to re-authenticate to fix "SAML enforcement" error by @mislav in gh#cli/cli#4241
  * Print warning when limit exceeds search API maximum by @despreston in gh#cli/cli#3967
  * Add git+https to the list of supported git remote URL protocols by @danburzo in gh#cli/cli#4347
  * Fix detecting the current gh executable in PATH by @wilso199 in gh#cli/cli#4243
  * Bump Survey library to fix the "Unexpected escape sequence" error by @mislav in gh#cli/cli#4405
  * Warn about missing OAuth scopes when printing HTTP 4xx errors by @mislav in gh#cli/cli#4513
* Fri Dec 10 2021 Emily Roberts <nopeinomicon@posteo.net>
- Fix boogh#cli/cli#1192421 - Changed git dependency to only git-core
* Thu Sep  2 2021 Emily Roberts <nopeinomicon@posteo.net>
- Update to version 2.0.0
  * Support for command extensions
  * Display label colors in issue list output gh#cli/cli#4106
  * Add tablerow/tablerender template functions for rendering data as tables gh#cli/cli#3519
  * Add GH_FORCE_TTY to enable terminal-style output even when redirected gh#cli/cli#4146
  * Add repo sync command to sync a branch with its upstream state gh#cli/cli#3813
  * Add pr checkout --branch flag to control the branch name gh#cli/cli#4005
  * Add release create --discussion-category flag gh#cli/cli#4003
  * Add config set browser option and GH_BROWSER environment variable gh#cli/cli#3992
  * Add repo list --topic filter gh#cli/cli#4136
  * Add PowerShell instructions to completion help gh#cli/cli#4114
  * Improve accessibility of interactive select menus gh#cli/cli#4172
  * Improve detection of truecolor terminal capabilities gh#cli/cli#4106
  * Avoid wrapping issues in powershell.exe gh#cli/cli#4106
  * Detect missing git and abort early during auth login flow gh#cli/cli#4109
  * Fix HTTP 502 error printing from GraphQL responses gh#cli/cli#4154
  * Require Go 1.16+ gh#cli/cli#4175
  * Remove backwards compatibility with homedir library for config files gh#cli/cli#4145
* Sat Aug  7 2021 Emily Roberts <nopeinomicon@posteo.net>
- Update to version 1.14.0
  * Improve shell completion gh#cli/cli#4028
  - Enable --json flag completion with multiple comma-separated fields
  - Add completion for repo create --gitignore flag
  - Add completion for repo create --license flag
  - Switch to Cobra's improved bash completion with descriptions
  - Enable descriptions in PowerShell completion gh#cli/cli#4085
  - Add completion of -R/--repo flag based on available git remotes gh#cli/cli#3942
  * Add pr merge --admin flag to allow admins to force-merge a pull request gh#cli/cli#4071
  * Fix authenticating with GH_ENTERPRISE_TOKEN and GH_HOST environment variables gh#cli/cli#4019
  * Fix labels display in issue list output gh#cli/cli#4079
  * Fix printing certain GraphQL errors gh#cli/cli#4087
* Wed Jul 28 2021 Emily Roberts <nopeinomicon@posteo.net>
- Update to version 1.13.1
  * Release fixes pre-built binaries, changes aren't applicable to this package
- Changes from 1.13.0
  * issue/pr view: output label names in their own color gh#cli/cli#3912
  * Add gh browse --no-browser to only print the URL gh#cli/cli#3943
  * repo create: respect privacy setting when using license/gitignore templates gh#cli/cli#3972
  * repo create: respect repository description when creating from template repository gh#cli/cli#3972
  * repo create --confirm: avoid license/gitignore template prompt gh#cli/cli#3995
  * pr merge --auto: merge immediately if the PR is already mergeable gh#cli/cli#3706
  * pr merge: suggest using --auto when merging is blocked gh#cli/cli#3706
  * Allow using cursor keys in interactive text inputs gh#cli/cli#3980
  * gh run watch --exit-status: correct exit status for completed runs gh#cli/cli#3982
  * Skip auto-migrate of config files when GH_CONFIG_DIR is set gh#cli/cli#4017
  * alias set: add note about double-quoting arguments for Command Prompt users gh#cli/cli#4013
  * Clean up GH_CONFIG_DIR docs gh#cli/cli#4020
- Changes from 1.12.1
  * Fix bug where branchProtectionRule doesn't exist in enterprise 2.22 gh#cli/cli#3922
  * Fix repo create in org with license/ignore gh#cli/cli#3924
- Changes from 1.12.0
  * Added gh browse command
  * Add .gitignore and LICENSE when creating repositories from scratch
  * A new config value http_unix_socket can be configured to a local path to push all traffic over a socket
  * Print help even if logged out gh#cli/cli#3850
  * Add shell completion for the --state flag gh#cli/cli#3877
  * Allow explicitly empty body in issue/pr create gh#cli/cli#3787
  * Increase GH_PAGER precedence gh#cli/cli#3789
  * Fix showing Checks information in pr status gh#cli/cli#3804
  * Update "Accept" header for github.com requests gh#cli/cli#3803
  * Fix setting environment secrets gh#cli/cli#3832
  * Fix gh run download fails on large artifacts due to uint32 limitation gh#cli/cli#3890
  * repo fork: check that --org is not the empty string gh#cli/cli#3807
  * Document installing via Conda package manager gh#cli/cli#3792
  * Fix description for gh secret set --env option gh#cli/cli#3784
  * Add a long command description for secrets remove gh#cli/cli#3786
  * Update documentation for gist create command with default of secret gh#cli/cli#3871
  * fork tests cleanup gh#cli/cli#3809
  * Remove unused method from httpmock package gh#cli/cli#3834
  * Factory cleanup gh#cli/cli#3841
  * Improvements to build script on Windows gh#cli/cli#3846
  * Ensure that tests for command factory never read from user's config gh#cli/cli#3856
* Wed Jun 23 2021 Martin Pluskal <mpluskal@suse.com>
- Update to version 1.11.0:
  * Add support for environment secrets gh#cli/cli#3270 gh#cli/cli#3769 gh#cli/cli#3774
  * run list: add "age" column and columns headers in output gh#cli/cli#3575
  * Add support for XDG Base Directory specification gh#cli/cli#3671 gh#cli/cli#3768 gh#cli/cli#3717
  * Additionally, the default configuration location on Windows is now changed from ~/.config/gh/ to %%AppData%%.
  * Include number alongside the title in issue/pr view gh#cli/cli#3741
* Tue Jun 15 2021 Christian Wittmer <chris@computersalat.de>
- fix build for SLES12
  * fix Supplements: packageand(X:Y)
* Sat May 22 2021 Mustafa Çalışkan <musfay@protonmail.com>
- Update to version 1.10.3:
  * Fix gh pr merge with GitHub Enterprise Server < 3.0 gh#cli/cli#3688
  * Speed up measuring display width of text gh#cli/cli#3668
  * Simplify Debian/Ubuntu installation docs gh#cli/cli#3672
- Changes from 1.10.2:
  * Fix creating Windows directory for gh config gh#cli/cli#3666
* Wed May 19 2021 Mustafa Çalışkan <musfay@protonmail.com>
- Update to version 1.10.1:
  * Fix pr checkout for cross-repository pull requests gh#cli/cli#3663
* Wed May 19 2021 Mustafa Çalışkan <musfay@protonmail.com>
- Update to version 1.10.0:
  - Improvements to JSON exporting
  * Add gh repo list/view --json support gh#cli/cli#3627
  * Add gh release view --json support gh#cli/cli#3656
  * Fixes numerous issues with gh pr list/view --json support gh#cli/cli#3547
  - fetching closed field
  - fetching date fields like createdAt or mergedAt
  - fetching files field
  * Fix exporting milestone field for issues and PRs gh#cli/cli#3529
  * Add commits field to JSON export for PRs gh#cli/cli#3547
  * Show more than 100 comments in gh issue view --json comments gh#cli/cli#3547
  * Add shell completion for valid --json flag values gh#cli/cli#3628
  - New Features
  * Add gh repo fork --org option gh#cli/cli#3611
  * Allow passinggh alias set value via standard input gh#cli/cli#3490
  * Prompt for value in gh secret set gh#cli/cli#3499
  * Update gh api placeholder syntax to {owner}, {repo} to match
    GitHub API documentation gh#cli/cli#3536
  * Extend our package repository to support Ubuntu Hirsute and
    Kali linux gh#cli/cli#3398
  - Fixes
  * Speedup across most gh pr commands gh#cli/cli#3547
  * Fix gh pr operations from GitHub Actions when a PR was added
    as a card to an org project gh#cli/cli#3547
  * Allow deleting local git branch in gh pr close gh#cli/cli#3547
  * Fix showing more than 100 checks in gh pr checks gh#cli/cli#3547
  * Fix viewing and editing draft releases with GitHub Actions token gh#cli/cli#3656
  * Fix Windows path in gh auth status output gh#cli/cli#3491
  * Ignore HTTP 404 error for annotations in gh run watch gh#cli/cli#3517
  * Handle Incorrect function exception for MinTTY users
    (typically in Git Bash) by suggesting switching to Windows Terminal gh#cli/cli#3537
  * Query fewer fields to determine issue status gh#cli/cli#3525
  * Warn about empty contents on gh gist create gh#cli/cli#3578
  * Fix "null" display in colored JSON output gh#cli/cli#3626
  * Fix some docs formatting for the web gh#cli/cli#3648
* Tue Apr 20 2021 Mustafa Çalışkan <musfay@protonmail.com>
- Update to version 1.9.2:
  - Actions Fixes
  * Fix Actions use int64 explicitly in Actions support gh#cli/cli#3432
  * Fix requesting REST sub-resources on GHE gh#cli/cli#3461
  * Fix run view --log when steps have slashes gh#cli/cli#3445
  * Include magic repo resolution magic for gh workflow and gh run gh#cli/cli#3468
  - Other Fixes
  * Fix issue create --web gh#cli/cli#3472
  * Fix detecting PR status when passing branch as arg gh#cli/cli#3351
  * Bump AlecAivazis/survey to fix bug with unicode input gh#cli/cli#3439
  - Development / Docs
  * Increase linter timeout from 1min to 3min gh#cli/cli#3462
  * Remove unused embedded struct gh#cli/cli#3402
  * Add note on supported value types in raw-fields gh#cli/cli#3400
  * linuxbrew details added in linux installation docs. gh#cli/cli#3465
  * Add Funtoo Linux install instructions gh#cli/cli#3438
  * Add Debian install variant without add-apt-repository gh#cli/cli#3419
* Mon Apr 19 2021 Mustafa Çalışkan <musfay@protonmail.com>
- Update to version 1.9.1:
  * Create cache dir
  * Fix whitespace formatting of `issue/pr view` help text
  * Disallow unsupported values for `--json` flag
  * Fix `pr view` tests broken by `createdAt` → `submittedAt` switch
  * Fix assigning null Exporter
  * Tests for GraphQL query builder and JSON exporter
  * Add `gh help formatting` topic & link to it from commands with JSON output
  * Placeholder consistency
  * Minor usage improvements
  * Bump run list limit
  * Annotation fixes
  * Unhide actions commands
  * Incorporate wording feedback
  * Fix small bug with startup_failure conclusion
  * Add note about current branch detection
- Prevent Makefile from overriding variables
- Enable tests
* Tue Apr 13 2021 Martin Pluskal <mpluskal@suse.com>
- Supplement bash-completion instead of bash
* Mon Apr 12 2021 Mustafa Çalışkan <musfay@protonmail.com>
- Update to version 1.8.1:
  * Fix pr status/checks crash with unrecognized statuse from
    the server(gh#cli/cli#3336)
  * Fix repo fork --clone not cloning an existing fork locally
    when running non-interactively(gh#cli/cli#3334)
  * Fix commands not respecting default hostname from GH_HOST(gh#cli/cli#3347)
- Create subpackages for completions
* Sun Mar  7 2021 Dirk Müller <dmueller@suse.com>
- update to 1.7.0:
  * see https://github.com/cli/cli/releases/tag/v1.7.0
  * https://github.com/cli/cli/releases/tag/v1.6.0
  * https://github.com/cli/cli/releases/tag/v1.5.0
* Fri Jan 22 2021 chris@computersalat.de
- fix build for SLES12
* Tue Dec 15 2020 Emily Roberts <nopeinomicon@posteo.net>
- Update to version 1.4.0
  * Add ability to view issue and pull request comment threads
  * Add management of GitHub Actions secrets
  * Set up git credentials when logging in to GitHub CLI
  * Add make install and make uninstall for POSIX systems when building from source
  * pr merge: attempt the merge even if mergeability status could not be determined
  * repo clone: enable cloning repository wikis
  * Recognize Include directives when parsing ssh config files
  * Display the new release notice only once per 24 hours
* Thu Dec 10 2020 Emily Roberts <nopeinomicon@posteo.net>
- Fix app not showing the correct version
- Install readme and license files
* Thu Dec 10 2020 Martin Pluskal <mpluskal@suse.com>
- Build and install manpages as well
* Wed Dec  9 2020 Emily Roberts <nopeinomicon@posteo.net>
- Use source specified at Source0 URL
- Switch from tar_scm to download_files for obtaining source archive
* Tue Dec  8 2020 Emily Roberts <nopeinomicon@posteo.net>
- Simplify BuildRequires
* Mon Dec  7 2020 Emily Roberts <nopeinomicon@posteo.net>
- Revert back to tar_scm service for submission to openSUSE:Factory
* Mon Dec  7 2020 nopeinomicon@posteo.net
- Update to version 1.3.1:
  * Allow interactive `pr create` even if we failed to look up commits
  * AskStubber now throws a more descriptive error when stubs do not match
  * Make MetadataSurvey testable by accepting an interface
  * Ensure efficient resolving of `issue/pr create` metadata to GraphQL IDs
  * don't reset previously added metadata
  * Prompt: avoid resetting PR/issue metadata if no option is selected
  * Fix "Continue in browser" for `pr create` coming from forks
  * Fix browser URL test on Windows
  * Fix respecting chosen action in interactive `issue create`
  * Properly check env auth tokens in CheckAuth
  * Delete an error message that is not useful (and had a typo)
  * Document that reviewers can be teams (gh#cli/cli#2465)
  * Bump AlecAivazis/survey
  * Sort latest PRs first when looking up PRs for a branch
* Wed Dec  2 2020 Emily Roberts <nopeinomicon@posteo.net>
- Reinstated and fixed obs_scm service for source control
- Fixed build for openSUSE Leap
* Mon Nov 30 2020 Emily Roberts <nopeinomicon@posteo.net>
- Return to tar_scm due to breakages with obs_scm service
* Wed Nov 25 2020 nopeinomicon@posteo.net
- Switch from tar_scm to obs_scm service
- Update to version 1.3.0:
  * Warn termux users with older Android versions (gh#cli/cli#2467)
  * no shorthand for --recover
  * switch to recover instead of resubmit
  * linter appeasement
  * use TempFile though the testing is gross
  * fix dumb test
  * preserve and restore issue/pr input on failure
  * add IOStreams.ReadUserFile
  * spelling: unmatched
  * spelling: template
  * spelling: settings
  * spelling: response
  * spelling: nonexistent
  * spelling: error
  * spelling: dunno
  * spelling: dismissed
  * spelling: deprecated
  * spelling: chestnuts
  * spelling: beginning
  * match parent repo protocol when forking (gh#cli/cli#2434)
  * respect GH_HOST when resolving remotes (gh#cli/cli#2301)
  * Add "reference" help topic (gh#cli/cli#2223)
  * Implement --web for gh pr checks (gh#cli/cli#2146)
  * Downgrade survey to v2.1.1
  * fix missing import
  * Support for --web when using gist create (gh#cli/cli#2263)
  * Add a command to delete a gist (gh#cli/cli#2265)
  * fix survey invocation
  * Fix USAGE help for some commands
  * add empty line between functions
  * Generate correct URL when branch option is passed in
  * add Draft to issue state
  * use NewIssueState
  * get everything working
  * stop using Defaults struct
  * stop using string pointer
  * WIP works, probably some title/body input edge cases
  * use named output param
  * Fix typos
  * Empty auth token env variables are equal to being unset
  * cleanup
  * Add support for GH_TOKEN and GH_ENTERPRISE_TOKEN
  * Consistently print commands in DEBUG mode
* Sun Nov 15 2020 Emily Roberts <nopeinomicon@posteo.net>
- Clean up .spec file
* Thu Nov 12 2020 nopeinomicon@posteo.net
- Update to version 1.2.1:
  * Fix git executable name for Windows in tests
  * Improve error message when git isn't found
  * Omit the full path of a command in DEBUG mode
  * Ensure that only PATH is searched when shelling out to external commands
  * Bump golang.org/x/text
  * Bump golang.org/x/crypto
  * Bump shurcooL/githubv4
  * Bump muesli/termenv
  * Bump mattn/go-colorable
  * Bump AlecAivazis/survey
  * Fix `truncateLabels` for empty values
  * Ensure parentheses are preserved after truncating labels in table view
  * Render links as absolute URLs in `repo view` (gh#cli/cli#2363)
  * Add Gentoo instructions to install the package (gh#cli/cli#2389)
  * Show MousetrapHelpText when double-clicking gh.exe
  * Small cleanup
  * Make markdown:generate annotation a markdown generation override for hidden commands
  * Generate markdown for help topics
  * Refactor help topics to include short message
  * Extract repeated code to util function
  * improve error message
  * Refactor regexp writer
  * Add multiple writes test
  * Use custom scanLines function for RegexWriter
  * Fix up regex to escape dot in URL
  * Address PR comments
  * Filter out unwanted stderr output during git push commands
  * new packages for get and set subcommands
  * Export type ConfigOption and group InvalidValueError code
  * Refactor config command
  * Cleanup duplicate config options
  * move cobra mutation and document it
  * Update install_linux.md
  * more iostreams passing
  * try passing iostreams around instead of writer+colorscheme
  * use shared color function
  * favor SuccessIcon
  * Use slice and make both status lines the size of the terminal width.
  * Use terminal width for the status line
  * port entirely to ColorScheme
  * added extra notes
  * Better tests for clone argument parsing
  * added Snap installation docs
  * Simplify checks test
  * add message on `pr checks` returns no CI with non-empty PR
  * Fetch all issue labels
  * Update triage.md
  * link to aliases
  * :nail_care: code style
  * :nail_care: simplify `sortPullRequestsByState`
  * PullRequestForBranch: fix outdated error message
  * Allow PullRequestForBranch to search in closed pull requests
  * Mention winget as an install option in README (gh#cli/cli#2272)
  * Small releasing docs cleanup
  * Update triage.md
  * Clean up and refactor unused doc generation code
  * Remove SEE ALSO from markdown docs generation
  * Remove Cobra autogenerated string from docs generation
  * Internalize doc generation from Cobra
  * Print friendly error when "gh repo clone" is missing required argument
  * removed runtime compare for windows The MousttrapHelpText will only be validated in cobra when running on windows.
  * run gh commands from explorer.exe
* Tue Nov 10 2020 Emily Roberts <nopeinomicon@posteo.net>
- Initial package version
